summaryrefslogtreecommitdiffstats
path: root/kword
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-21 14:05:41 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-21 14:05:41 -0600
commit2d6954f69caf63ed5057bd8e1405a65d7d970292 (patch)
tree88e6436b2e81d4e68313f02a9021054252e14cc4 /kword
parentf0de9e167e289ab7dc33e57f077c1f04ec7c68c8 (diff)
downloadkoffice-2d6954f69caf63ed5057bd8e1405a65d7d970292.tar.gz
koffice-2d6954f69caf63ed5057bd8e1405a65d7d970292.zip
Rename obsolete tq methods to standard names
Diffstat (limited to 'kword')
-rw-r--r--kword/DESIGN10
-rw-r--r--kword/HACKING4
-rw-r--r--kword/KWAnchor.cpp2
-rw-r--r--kword/KWCanvas.cpp8
-rw-r--r--kword/KWCommand.cpp64
-rw-r--r--kword/KWCommand.h4
-rw-r--r--kword/KWConfig.cpp4
-rw-r--r--kword/KWConfigFootNoteDia.cpp16
-rw-r--r--kword/KWCreateBookmarkDiaBase.ui2
-rw-r--r--kword/KWDocument.cpp78
-rw-r--r--kword/KWDocument.h18
-rw-r--r--kword/KWEditPersonnalExpression.cpp38
-rw-r--r--kword/KWFormulaFrameSet.cpp2
-rw-r--r--kword/KWFrame.h2
-rw-r--r--kword/KWFrameDia.cpp34
-rw-r--r--kword/KWFrameLayout.cpp16
-rw-r--r--kword/KWFrameLayout.h10
-rw-r--r--kword/KWFrameSet.cpp2
-rw-r--r--kword/KWFrameSet.h4
-rw-r--r--kword/KWFrameStyleManager.cpp6
-rw-r--r--kword/KWImportStyleDia.cpp2
-rw-r--r--kword/KWInsertPageDia.cpp2
-rw-r--r--kword/KWInsertTOCCommand.cpp2
-rw-r--r--kword/KWMailMergeDataBase.cpp32
-rw-r--r--kword/KWMailMergeLabelAction.cpp4
-rw-r--r--kword/KWOasisLoader.cpp2
-rw-r--r--kword/KWPageManager.cpp4
-rw-r--r--kword/KWPageManager.h2
-rw-r--r--kword/KWSortDia.cpp2
-rw-r--r--kword/KWStartupWidget.cpp6
-rw-r--r--kword/KWStartupWidget.h2
-rw-r--r--kword/KWTableFrameSet.cpp4
-rw-r--r--kword/KWTableFrameSet.h2
-rw-r--r--kword/KWTableStyleManager.cpp8
-rw-r--r--kword/KWTableTemplateSelector.cpp2
-rw-r--r--kword/KWTextFrameSet.cpp26
-rw-r--r--kword/KWTextFrameSet.h12
-rw-r--r--kword/KWTextParag.cpp36
-rw-r--r--kword/KWTextParag.h4
-rw-r--r--kword/KWVariable.cpp6
-rw-r--r--kword/KWView.cpp62
-rw-r--r--kword/KWView.h6
-rw-r--r--kword/KWViewMode.cpp58
-rw-r--r--kword/KWViewMode.h6
-rw-r--r--kword/KWordFrameSetIface.cpp8
-rw-r--r--kword/OASIS4
-rw-r--r--kword/mailmerge/kabc/addresspicker.ui4
-rw-r--r--kword/mailmerge/kspread/kwmailmerge_kspread_config.cpp10
-rw-r--r--kword/tests/KWPageManagerTester.cpp28
49 files changed, 335 insertions, 335 deletions
diff --git a/kword/DESIGN b/kword/DESIGN
index a920c8db..6a01ae28 100644
--- a/kword/DESIGN
+++ b/kword/DESIGN
@@ -38,7 +38,7 @@ cell, we contain the cells in their own KWTextFrameset.
is defined by m_zOrder in KWFrame. This number is relative to the other
frames *on the same page*.
-Frame tqlayout and pages
+Frame layout and pages
======================
Generally, the user is free to position frames where he/she wants to.
@@ -63,10 +63,10 @@ In WP mode, removing pages is automatically done by KWDocument::tryRemovingPages
In DTP mode pages are user-controlled (insert and delete page actions),
but overflowing text can still create a new page as well.
-The difficulty with frame tqlayout is that in most cases the frame size and
-number depends on the text inside, and the text tqlayout depends on the frames
-(frame width, frames on top, etc.). This is why text tqlayout (formatMore())
-and frame tqlayout (e.g. KWFrameLayout) often call each other, resulting in
+The difficulty with frame layout is that in most cases the frame size and
+number depends on the text inside, and the text layout depends on the frames
+(frame width, frames on top, etc.). This is why text layout (formatMore())
+and frame layout (e.g. KWFrameLayout) often call each other, resulting in
infinite loops when some code goes wrong.
Editing
diff --git a/kword/HACKING b/kword/HACKING
index c808ac27..e0ce97a5 100644
--- a/kword/HACKING
+++ b/kword/HACKING
@@ -59,7 +59,7 @@ DIRECTORIES:
various QTSQL interface implementation files
to handle table selection and mailmerge data
templates:
- various page tqlayout templates
+ various page layout templates
make_template.pl - Perl script to create XML templates
- from KWord-saved XML files
subdirectories
@@ -89,7 +89,7 @@ FILES:
main.cc - the main
kwaboutdata.h - the appname, authors...
- shared between main.cc and kwfactory.cc
- kword.rc - xml-gui tqlayout
+ kword.rc - xml-gui layout
kword.desktop - application .desktop file
main document data structures:
diff --git a/kword/KWAnchor.cpp b/kword/KWAnchor.cpp
index 6e99f0c9..a291999e 100644
--- a/kword/KWAnchor.cpp
+++ b/kword/KWAnchor.cpp
@@ -70,7 +70,7 @@ void KWAnchor::finalize()
void KWAnchor::draw( TQPainter* p, int x, int y, int cx, int cy, int cw, int ch, const TQColorGroup& cg, bool selected )
{
// (x,y) is the position of the inline item (in Layout Units)
- // (cx,cy,cw,ch) is the rectangle to be painted, in tqlayout units too
+ // (cx,cy,cw,ch) is the rectangle to be painted, in layout units too
if ( m_deleted )
return;
diff --git a/kword/KWCanvas.cpp b/kword/KWCanvas.cpp
index 58baa44b..4a469cca 100644
--- a/kword/KWCanvas.cpp
+++ b/kword/KWCanvas.cpp
@@ -305,7 +305,7 @@ void KWCanvas::drawFrameSet( KWFrameSet * frameset, TQPainter * painter,
if ( painter->device()->devType() == TQInternal::Printer )
focus = false;
- TQColorGroup gb = TQApplication::tqpalette().active();
+ TQColorGroup gb = TQApplication::palette().active();
if ( focus && m_currentFrameSetEdit && frameset == m_currentFrameSetEdit->frameSet() )
// Currently edited frameset
m_currentFrameSetEdit->drawContents( painter, crect, gb, onlyChanged, resetChanged, viewMode, m_frameViewManager );
@@ -543,9 +543,9 @@ void KWCanvas::contentsMousePressEvent( TQMouseEvent *e )
if ( e->button() == Qt::MidButton ) {
if ( m_doc->isReadWrite() && m_currentFrameSetEdit && m_mouseMode == MM_EDIT )
{
- TQApplication::tqclipboard()->setSelectionMode( true );
+ TQApplication::clipboard()->setSelectionMode( true );
m_currentFrameSetEdit->paste();
- TQApplication::tqclipboard()->setSelectionMode( false );
+ TQApplication::clipboard()->setSelectionMode( false );
}
}
else if ( e->button() == Qt::RightButton ) {
@@ -1032,7 +1032,7 @@ void KWCanvas::mrCreateTable()
emit docStructChanged(Tables);
}
m_doc->updateAllFrames();
- m_doc->tqlayout();
+ m_doc->layout();
repaintAll();
}
diff --git a/kword/KWCommand.cpp b/kword/KWCommand.cpp
index 8c1d0e69..20a4c918 100644
--- a/kword/KWCommand.cpp
+++ b/kword/KWCommand.cpp
@@ -145,14 +145,14 @@ KoTextCursor * KWPasteTextCommand::execute( KoTextCursor *c )
break;
}
TQDomElement paragElem = *it;
- // First line (if appending to non-empty line) : apply offset to formatting, don't apply parag tqlayout
+ // First line (if appending to non-empty line) : apply offset to formatting, don't apply parag layout
if ( item == 0 && m_idx > 0 )
{
// First load the default format, but only apply it to our new chars
- TQDomElement tqlayout = paragElem.namedItem( "LAYOUT" ).toElement();
- if ( !tqlayout.isNull() )
+ TQDomElement layout = paragElem.namedItem( "LAYOUT" ).toElement();
+ if ( !layout.isNull() )
{
- TQDomElement formatElem = tqlayout.namedItem( "FORMAT" ).toElement();
+ TQDomElement formatElem = layout.namedItem( "FORMAT" ).toElement();
if ( !formatElem.isNull() )
{
KoTextFormat f = parag->loadFormat( formatElem, 0L, TQFont(), KGlobal::locale()->language(),false );
@@ -167,7 +167,7 @@ KoTextCursor * KWPasteTextCommand::execute( KoTextCursor *c )
}
else
{
- if ( item == 0 ) // This paragraph existed, store its parag tqlayout
+ if ( item == 0 ) // This paragraph existed, store its parag layout
{
delete m_oldParagLayout;
m_oldParagLayout = new KoParagLayout( parag->paragLayout() );
@@ -913,7 +913,7 @@ KWFrameMoveCommand::KWFrameMoveCommand( const TQString &name,
void KWFrameMoveCommand::execute()
{
- bool needRetqlayout = false;
+ bool needRelayout = false;
KWDocument * doc = 0L;
TQValueList<FrameMoveStruct>::Iterator moveIt = m_frameMove.begin();
TQValueList<FrameIndex>::Iterator tmp = m_indexFrame.begin();
@@ -925,13 +925,13 @@ void KWFrameMoveCommand::execute()
frame->moveTopLeft( (*moveIt).newPos );
frame->updateRulerHandles();
- needRetqlayout = needRetqlayout || ( frame->runAround() != KWFrame::RA_NO );
+ needRelayout = needRelayout || ( frame->runAround() != KWFrame::RA_NO );
}
if ( doc )
{
doc->updateAllFrames();
- if ( needRetqlayout )
- doc->tqlayout();
+ if ( needRelayout )
+ doc->layout();
doc->updateRulerFrameStartEnd();
doc->repaintAllViews();
@@ -940,7 +940,7 @@ void KWFrameMoveCommand::execute()
void KWFrameMoveCommand::unexecute()
{
- bool needRetqlayout = false;
+ bool needRelayout = false;
KWDocument * doc = 0L;
TQValueList<FrameMoveStruct>::Iterator moveIt = m_frameMove.begin();
TQValueList<FrameIndex>::Iterator tmp = m_indexFrame.begin();
@@ -952,14 +952,14 @@ void KWFrameMoveCommand::unexecute()
frame->moveTopLeft( (*moveIt).oldPos );
frame->updateRulerHandles();
- needRetqlayout = needRetqlayout || ( frame->runAround() != KWFrame::RA_NO );
+ needRelayout = needRelayout || ( frame->runAround() != KWFrame::RA_NO );
}
if ( doc )
{
doc->updateAllFrames();
- if ( needRetqlayout )
- doc->tqlayout();
+ if ( needRelayout )
+ doc->layout();
doc->updateRulerFrameStartEnd();
doc->repaintAllViews();
}
@@ -995,7 +995,7 @@ void KWFramePropertiesCommand::execute()
{
doc->frameChanged( frame );
doc->updateAllFrames();
- doc->tqlayout();
+ doc->layout();
doc->repaintAllViews();
doc->updateRulerFrameStartEnd();
}
@@ -1016,7 +1016,7 @@ void KWFramePropertiesCommand::unexecute()
{
doc->frameChanged( frame );
doc->updateAllFrames();
- doc->tqlayout();
+ doc->layout();
doc->repaintAllViews();
doc->updateRulerFrameStartEnd();
}
@@ -1226,7 +1226,7 @@ void KWDeleteTableCommand::execute()
doc->refreshDocStructure((int)Tables);
doc->updateAllFrames();
m_pTable->updateFrames(); // not in the doc list anymore, so the above call didn't do it!
- doc->tqlayout();
+ doc->layout();
doc->repaintAllViews();
doc->updateRulerFrameStartEnd();
@@ -1240,7 +1240,7 @@ void KWDeleteTableCommand::unexecute()
doc->addFrameSet(m_pTable);
doc->refreshDocStructure((int)Tables);
doc->updateAllFrames();
- doc->tqlayout();
+ doc->layout();
doc->repaintAllViews();
doc->updateRulerFrameStartEnd();
}
@@ -1284,7 +1284,7 @@ void KWInsertColumnCommand::execute()
}
Q_ASSERT(m_pTable->boundingRect().right() <= m_maxRight);
doc->updateAllFrames();
- doc->tqlayout();
+ doc->layout();
doc->repaintAllViews();
}
@@ -1300,7 +1300,7 @@ void KWInsertColumnCommand::unexecute()
m_pTable->resizeWidth(m_oldWidth);
}
doc->updateAllFrames();
- doc->tqlayout();
+ doc->layout();
doc->repaintAllViews();
}
@@ -1332,7 +1332,7 @@ void KWInsertRowCommand::execute()
m_pTable->insertNewRow(m_rowPos); //only happens the first time
}
doc->updateAllFrames();
- doc->tqlayout();
+ doc->layout();
doc->repaintAllViews();
}
@@ -1345,7 +1345,7 @@ void KWInsertRowCommand::unexecute()
m_pTable->deleteRow( m_rowPos, *m_rr);
doc->updateAllFrames();
- doc->tqlayout();
+ doc->layout();
}
@@ -1372,7 +1372,7 @@ void KWRemoveRowCommand::execute()
m_pTable->deleteRow( m_rowPos, *m_rr);
doc->updateAllFrames();
- doc->tqlayout();
+ doc->layout();
}
void KWRemoveRowCommand::unexecute()
@@ -1381,7 +1381,7 @@ void KWRemoveRowCommand::unexecute()
KWDocument * doc = m_pTable->kWordDocument();
m_pTable->reInsertRow(*m_rr);
doc->updateAllFrames();
- doc->tqlayout();
+ doc->layout();
doc->repaintAllViews();
}
@@ -1407,7 +1407,7 @@ void KWRemoveColumnCommand::execute()
m_pTable->deleteColumn( m_colPos, *m_rc);
doc->updateAllFrames();
- doc->tqlayout();
+ doc->layout();
}
void KWRemoveColumnCommand::unexecute()
@@ -1416,7 +1416,7 @@ void KWRemoveColumnCommand::unexecute()
KWDocument * doc = m_pTable->kWordDocument();
m_pTable->reInsertColumn(*m_rc);
doc->updateAllFrames();
- doc->tqlayout();
+ doc->layout();
doc->repaintAllViews();
}
@@ -1441,7 +1441,7 @@ void KWSplitCellCommand::execute()
//kdDebug()<<"split Cell m_colBegin :"<<m_colBegin<<" m_colEnd :"<<m_colEnd<<" m_rowBegin :"<<m_rowBegin<<" m_colEnd :"<<m_colEnd<<endl;
m_pTable->splitCell(m_rowEnd, m_colEnd,m_colBegin,m_rowBegin,m_ListFrameSet);
doc->updateAllFrames();
- doc->tqlayout();
+ doc->layout();
}
void KWSplitCellCommand::unexecute()
@@ -1478,7 +1478,7 @@ void KWSplitCellCommand::unexecute()
m_rowBegin+m_rowEnd-1+cell->rowSpan()-1);
doc->updateAllFrames();
- doc->tqlayout();
+ doc->layout();
}
@@ -1507,7 +1507,7 @@ void KWJoinCellCommand::execute()
doc->terminateEditing(m_pTable);
m_pTable->joinCells(m_colBegin,m_rowBegin,m_colEnd,m_rowEnd);
doc->updateAllFrames();
- doc->tqlayout();
+ doc->layout();
}
void KWJoinCellCommand::unexecute()
@@ -1517,7 +1517,7 @@ void KWJoinCellCommand::unexecute()
doc->terminateEditing(m_pTable);
m_pTable->splitCell(m_rowEnd-m_rowBegin+1, m_colEnd-m_colBegin+1,m_colBegin,m_rowBegin,m_ListFrameSet,m_copyFrame);
doc->updateAllFrames();
- doc->tqlayout();
+ doc->layout();
}
@@ -1986,7 +1986,7 @@ void KWChangeFootNoteParametersCommand::changeVariableParameter( FootNoteParamet
if ( frameset)
frameset->renumberFootNotes();
- // Re-tqlayout the footnote/endnote frame
+ // Re-layout the footnote/endnote frame
KWFrame* footNoteFrame = m_var->frameSet()->frame( 0 );
int framePage = footNoteFrame->pageNumber();
m_doc->recalcFrames( framePage, -1 );
@@ -2061,14 +2061,14 @@ KWResizeColumnCommand::KWResizeColumnCommand( KWTableFrameSet *table, int col, d
void KWResizeColumnCommand::execute()
{
m_table->resizeColumn(m_col, m_newSize);
- m_table->kWordDocument()->tqlayout();
+ m_table->kWordDocument()->layout();
m_table->kWordDocument()->repaintAllViews();
}
void KWResizeColumnCommand::unexecute()
{
m_table->resizeColumn(m_col, m_oldSize);
- m_table->kWordDocument()->tqlayout();
+ m_table->kWordDocument()->layout();
m_table->kWordDocument()->repaintAllViews();
}
diff --git a/kword/KWCommand.h b/kword/KWCommand.h
index 7c905fb3..71d13f1f 100644
--- a/kword/KWCommand.h
+++ b/kword/KWCommand.h
@@ -380,7 +380,7 @@ protected:
bool m_oldValue;
};
-///////////////////////////////tqlayout command///////////////////////////
+///////////////////////////////layout command///////////////////////////
struct KWPageLayoutStruct {
KWPageLayoutStruct( const KoPageLayout& pgLayout, const KoColumns& cl, const KoKWHeaderFooter& hf )
: _pgLayout(pgLayout), _cl(cl), _hf(hf) {
@@ -391,7 +391,7 @@ struct KWPageLayoutStruct {
};
/**
- * Command created when changing the page tqlayout
+ * Command created when changing the page layout
*/
class KWPageLayoutCommand : public KNamedCommand
{
diff --git a/kword/KWConfig.cpp b/kword/KWConfig.cpp
index b368af2e..e3a56ac4 100644
--- a/kword/KWConfig.cpp
+++ b/kword/KWConfig.cpp
@@ -217,7 +217,7 @@ ConfigureSpellPage::ConfigureSpellPage( KWView *view, TQVBox *box, char *name )
config = KWFactory::instance()->config();
m_spellConfigWidget = new ConfigWidget( view->broker(), box );
m_spellConfigWidget->setBackgroundCheckingButtonShown( true );
- m_spellConfigWidget->tqlayout()->setMargin( 0 );
+ m_spellConfigWidget->layout()->setMargin( 0 );
}
void ConfigureSpellPage::apply()
@@ -655,7 +655,7 @@ KCommand *ConfigureMiscPage::apply()
}
if ( needRepaint )
{
- doc->tqlayout();
+ doc->layout();
doc->repaintAllViews();
}
return macroCmd;
diff --git a/kword/KWConfigFootNoteDia.cpp b/kword/KWConfigFootNoteDia.cpp
index d15c78c0..ee235c9b 100644
--- a/kword/KWConfigFootNoteDia.cpp
+++ b/kword/KWConfigFootNoteDia.cpp
@@ -81,7 +81,7 @@ void KWConfigFootNoteDia::setupTab3()
"of the three alignments.");
TQWhatsThis::add(positionGroupBox, comment);
positionGroupBox->setColumnLayout(0, Qt::Vertical );
- TQVBoxLayout *positionLayout = new TQVBoxLayout( positionGroupBox->tqlayout() );
+ TQVBoxLayout *positionLayout = new TQVBoxLayout( positionGroupBox->layout() );
positionLayout->setAlignment( TQt::AlignTop );
// i18n context information necessary for gender considerations (e.g. in Polish)
@@ -106,35 +106,35 @@ void KWConfigFootNoteDia::setupTab3()
break;
}
- TQGridLayout *tqlayout = new TQGridLayout( 0, 1, 1, 0, KDialog::spacingHint());
+ TQGridLayout *layout = new TQGridLayout( 0, 1, 1, 0, KDialog::spacingHint());
spWidth = new KoUnitDoubleSpinBox(page, 0, 5, 0.5, m_doc->footNoteSeparatorLineWidth(), m_doc->unit(), 1);
- tqlayout->addWidget( spWidth, 1, 1 );
+ layout->addWidget( spWidth, 1, 1 );
spLength = new KIntNumInput( page, "spLength" );
spLength->setRange( 1, 100, 1,false );
spLength->setValue( m_doc->footNoteSeparatorLineLength());
spLength->setSuffix(i18n(" %"));
- tqlayout->addWidget( spLength, 0, 1 );
+ layout->addWidget( spLength, 0, 1 );
TQLabel *lSize = new TQLabel( i18n( "&Width:"), page );
lSize->setBuddy( spWidth );
comment= i18n ("The width is the thickness of the separator line, set to 0 for no separator line.");
TQWhatsThis::add(lSize, comment);
TQWhatsThis::add(spWidth, comment);
- tqlayout->addWidget( lSize, 1, 0 );
+ layout->addWidget( lSize, 1, 0 );
TQSpacerItem* spacer = new TQSpacerItem( 0, 0, TQSizePolicy::Expanding, TQSizePolicy::Minimum );
- tqlayout->addMultiCell( spacer, 0, 1, 2, 2 );
+ layout->addMultiCell( spacer, 0, 1, 2, 2 );
TQLabel *lWidth = new TQLabel( i18n("&Size on page:"), page, "lWidth" );
lWidth->setBuddy( spLength );
comment= i18n ("The size of the separator line can be defined as a percentage of the width of the page.");
TQWhatsThis::add(spLength, comment);
TQWhatsThis::add(lWidth, comment);
- tqlayout->addWidget( lWidth, 0, 0 );
- pageLayout->addLayout( tqlayout );
+ layout->addWidget( lWidth, 0, 0 );
+ pageLayout->addLayout( layout );
TQHBoxLayout *styleLayout = new TQHBoxLayout( 0, 0, KDialog::spacingHint(), "styleLayout");
diff --git a/kword/KWCreateBookmarkDiaBase.ui b/kword/KWCreateBookmarkDiaBase.ui
index 0d164ed4..e789ac28 100644
--- a/kword/KWCreateBookmarkDiaBase.ui
+++ b/kword/KWCreateBookmarkDiaBase.ui
@@ -21,7 +21,7 @@
</property>
<widget class="TQLayoutWidget" row="1" column="0">
<property name="name">
- <cstring>tqlayout2</cstring>
+ <cstring>layout2</cstring>
</property>
<hbox>
<property name="name">
diff --git a/kword/KWDocument.cpp b/kword/KWDocument.cpp
index 271359ba..55f5f351 100644
--- a/kword/KWDocument.cpp
+++ b/kword/KWDocument.cpp
@@ -483,8 +483,8 @@ void KWDocument::newZoomAndResolution( bool updateViews, bool forPrint )
// First recalc all frames (including the kotextdocument width)
updateAllFrames();
- // Then retqlayout the text inside the frames
- tqlayout();
+ // Then relayout the text inside the frames
+ layout();
if ( updateViews )
{
emit newContentsSize();
@@ -617,9 +617,9 @@ KoPageLayout KWDocument::pageLayout(int pageNumber /* = 0 */) const
return pageManager()->pageLayout(pageNumber);
}
-void KWDocument::setPageLayout( const KoPageLayout& tqlayout, const KoColumns& cl, const KoKWHeaderFooter& hf, bool updateViews )
+void KWDocument::setPageLayout( const KoPageLayout& layout, const KoColumns& cl, const KoKWHeaderFooter& hf, bool updateViews )
{
- m_pageLayout = tqlayout;
+ m_pageLayout = layout;
if ( m_processingType == WP ) {
m_pageColumns = cl;
}
@@ -643,8 +643,8 @@ void KWDocument::setPageLayout( const KoPageLayout& tqlayout, const KoColumns& c
if ( updateViews )
{
- // Invalidate document tqlayout, for proper repaint
- this->tqlayout();
+ // Invalidate document layout, for proper repaint
+ this->layout();
emit pageLayoutChanged( m_pageLayout );
updateContentsSize();
}
@@ -953,10 +953,10 @@ void KWDocument::recalcFrames( int fromPage, int toPage /*-1 for all*/, uint fla
if ( fromPage > toPage ) // this can happen with "endnotes only" pages :) // ### really?
fromPage = toPage; // ie. start at the last real page
KWFrameLayout frameLayout( this, headerFooterList, footnotesHFList, endnotesHFList );
- frameLayout.tqlayout( frameset, m_pageColumns.columns, fromPage, toPage, flags );
+ frameLayout.layout( frameset, m_pageColumns.columns, fromPage, toPage, flags );
// If the number of pages changed, update views and variables etc.
- // (now that the frame tqlayout has been done)
+ // (now that the frame layout has been done)
if ( pageCount() != oldPages && !m_bGeneratingPreview )
{
// Very much like the end of appendPage, but we don't want to call recalcFrames ;)
@@ -1072,7 +1072,7 @@ bool KWDocument::loadOasis( const TQDomDocument& doc, KoOasisStyles& oasisStyles
// In theory the page format is the style:master-page-name of the first paragraph...
// But, hmm, in a doc with only a table there was no reference to the master page at all...
- // So we load the standard page tqlayout to start with, and in KWTextParag
+ // So we load the standard page layout to start with, and in KWTextParag
// we might overwrite it with another one.
m_loadingInfo->m_currentMasterPage = "Standard";
if ( !loadOasisPageLayout( m_loadingInfo->m_currentMasterPage, context ) )
@@ -1133,12 +1133,12 @@ bool KWDocument::loadOasis( const TQDomDocument& doc, KoOasisStyles& oasisStyles
// load padding, background and borders for the main frame
const TQDomElement* masterPage = context.oasisStyles().masterPages()[ m_loadingInfo->m_currentMasterPage ];
- const TQDomElement *masterPageStyle = masterPage ? context.oasisStyles().findStyle(masterPage->attributeNS( KoXmlNS::style, "page-tqlayout-name", TQString() ) ) : 0;
+ const TQDomElement *masterPageStyle = masterPage ? context.oasisStyles().findStyle(masterPage->attributeNS( KoXmlNS::style, "page-layout-name", TQString() ) ) : 0;
if ( masterPageStyle )
{
KoStyleStack styleStack;
styleStack.push( *masterPageStyle );
- styleStack.setTypeProperties( "page-tqlayout" );
+ styleStack.setTypeProperties( "page-layout" );
frame->loadBorderProperties( styleStack );
}
fs->renumberFootNotes( false /*no repaint*/ );
@@ -1152,7 +1152,7 @@ bool KWDocument::loadOasis( const TQDomDocument& doc, KoOasisStyles& oasisStyles
const TQString localName = tag.localName();
if ( localName == "page-sequence" && tag.namespaceURI() == KoXmlNS::text )
{
- // We don't have support for changing the page tqlayout yet, so just take the
+ // We don't have support for changing the page layout yet, so just take the
// number of pages
int pages=1;
TQDomElement page;
@@ -1205,14 +1205,14 @@ bool KWDocument::loadOasisPageLayout( const TQString& masterPageName, KoOasisCon
const KoOasisStyles& oasisStyles = context.oasisStyles();
const TQDomElement* masterPage = oasisStyles.masterPages()[ masterPageName ];
Q_ASSERT( masterPage );
- const TQDomElement *masterPageStyle = masterPage ? oasisStyles.findStyle( masterPage->attributeNS( KoXmlNS::style, "page-tqlayout-name", TQString() ) ) : 0;
+ const TQDomElement *masterPageStyle = masterPage ? oasisStyles.findStyle( masterPage->attributeNS( KoXmlNS::style, "page-layout-name", TQString() ) ) : 0;
Q_ASSERT( masterPageStyle );
if ( masterPageStyle )
{
m_pageLayout.loadOasis( *masterPageStyle );
pageManager()->setDefaultPage(m_pageLayout);
- const TQDomElement properties( KoDom::namedItemNS( *masterPageStyle, KoXmlNS::style, "page-tqlayout-properties" ) );
+ const TQDomElement properties( KoDom::namedItemNS( *masterPageStyle, KoXmlNS::style, "page-layout-properties" ) );
const TQDomElement footnoteSep = KoDom::namedItemNS( properties, KoXmlNS::style, "footnote-sep" );
if ( !footnoteSep.isNull() ) {
// style:width="0.018cm" style:distance-before-sep="0.101cm"
@@ -1292,19 +1292,19 @@ bool KWDocument::loadMasterPageStyle( const TQString& masterPageName, KoOasisCon
const KoOasisStyles& oasisStyles = context.oasisStyles();
const TQDomElement* masterPage = oasisStyles.masterPages()[ masterPageName ];
Q_ASSERT( masterPage );
- const TQDomElement *masterPageStyle = masterPage ? oasisStyles.findStyle( masterPage->attributeNS( KoXmlNS::style, "page-tqlayout-name", TQString() ) ) : 0;
+ const TQDomElement *masterPageStyle = masterPage ? oasisStyles.findStyle( masterPage->attributeNS( KoXmlNS::style, "page-layout-name", TQString() ) ) : 0;
Q_ASSERT( masterPageStyle );
// This check is done here and not in loadOasisPageLayout in case the Standard master-page
// has no page information but the first paragraph points to a master-page that does (#129585)
if ( m_pageLayout.ptWidth <= 1e-13 || m_pageLayout.ptHeight <= 1e-13 )
{
- // Loading page tqlayout failed, try to see why.
- TQDomElement properties( KoDom::namedItemNS( *masterPageStyle, KoXmlNS::style, "page-tqlayout-properties" ) );
+ // Loading page layout failed, try to see why.
+ TQDomElement properties( KoDom::namedItemNS( *masterPageStyle, KoXmlNS::style, "page-layout-properties" ) );
//if ( properties.isNull() )
- // setErrorMessage( i18n( "Invalid document. No page tqlayout properties were found. The application which produced this document isn't OASIS-compliant." ) );
+ // setErrorMessage( i18n( "Invalid document. No page layout properties were found. The application which produced this document isn't OASIS-compliant." ) );
//else if ( properties.hasAttributeNS( KoXmlNS::fo, "page-width" ) )
- // setErrorMessage( i18n( "Invalid document. Page tqlayout has no page width. The application which produced this document isn't OASIS-compliant." ) );
+ // setErrorMessage( i18n( "Invalid document. Page layout has no page width. The application which produced this document isn't OASIS-compliant." ) );
//else
if ( properties.hasAttributeNS( "http://www.w3.org/1999/XSL/Format", "page-width" ) )
setErrorMessage( i18n( "Invalid document. 'fo' has the wrong namespace. The application which produced this document is not OASIS-compliant." ) );
@@ -2705,7 +2705,7 @@ void KWDocument::completePasting()
processAnchorRequests();
if ( processFootNoteRequests() )
{
- // We pasted footnotes. Retqlayout frames.
+ // We pasted footnotes. Relayout frames.
recalcFrames();
}
@@ -2837,7 +2837,7 @@ bool KWDocument::saveOasisHelper( KoStore* store, KoXmlWriter* manifestWriter, S
}
// Header and footers save their content into master-styles/master-page, and their
- // styles into the page-tqlayout automatic-style.
+ // styles into the page-layout automatic-style.
// However the paragraph styles used by header/footers need to be known before
// hand, to promote them to styles.xml. So we collect them first, which means
// storing the content into a buffer.
@@ -3251,8 +3251,8 @@ void KWDocument::saveOasisDocumentStyles( KoStore* store, KoGenStyles& mainStyle
// if there's more than one pagemaster we need to rethink all this
pageLayoutName = mainStyles.lookup( pageLayout, "pm" );
- pageLayout.writeStyle( stylesWriter, mainStyles, "style:page-tqlayout", pageLayoutName,
- "style:page-tqlayout-properties", false /*don't close*/ );
+ pageLayout.writeStyle( stylesWriter, mainStyles, "style:page-layout", pageLayoutName,
+ "style:page-layout-properties", false /*don't close*/ );
// Ouch another problem: there is only one header style in oasis
// ##### can't have different borders for even/odd headers...
@@ -3301,7 +3301,7 @@ void KWDocument::saveOasisDocumentStyles( KoStore* store, KoGenStyles& mainStyle
stylesWriter->endElement(); // header-style
}
}
- stylesWriter->endElement(); // style:page-tqlayout
+ stylesWriter->endElement(); // style:page-layout
// Headers and footers might have created new automatic parag/text styles -> save those
KWOasisSaver::writeAutomaticStyles( *stylesWriter, mainStyles, true );
@@ -3313,7 +3313,7 @@ void KWDocument::saveOasisDocumentStyles( KoStore* store, KoGenStyles& mainStyle
stylesWriter->startElement( "office:master-styles" );
stylesWriter->startElement( "style:master-page" );
stylesWriter->addAttribute( "style:name", "Standard" );
- stylesWriter->addAttribute( "style:page-tqlayout-name", pageLayoutName );
+ stylesWriter->addAttribute( "style:page-layout-name", pageLayoutName );
if ( isHeaderVisible() || isFooterVisible() ) { // ### TODO save them even when hidden (and not empty)?
stylesWriter->addCompleteElement( headerFooterContent.data() );
@@ -3779,7 +3779,7 @@ void KWDocument::paintContent( TQPainter& painter, const TQRect& rectangle, bool
viewMode->setDrawFrameBackground( !transparent );
viewMode->setDrawSelections( false );
- TQColorGroup cg = TQApplication::tqpalette().active();
+ TQColorGroup cg = TQApplication::palette().active();
if (!transparent)
{
@@ -3810,7 +3810,7 @@ TQPixmap KWDocument::generatePreview( const TQSize& size )
double oldZoomX = zoomedResolutionX();
double oldZoomY = zoomedResolutionY();
- // Sometimes (due to the different resolution?) the tqlayout creates a new page
+ // Sometimes (due to the different resolution?) the layout creates a new page
// while saving the preview. If this happens, we don't want to repaint the real views
// (due to KWCanvas::slotNewContentsSize)
// ##### One day when we have real doc/view separation in kotextparag, we shouldn't mess with
@@ -4364,7 +4364,7 @@ void KWDocument::setHeaderVisible( bool h )
m_headerVisible = h;
recalcFrames();
updateAllFrames();
- tqlayout();
+ layout();
setModified(true);
repaintAllViews( true );
}
@@ -4374,7 +4374,7 @@ void KWDocument::setFooterVisible( bool f )
m_footerVisible = f;
recalcFrames();
updateAllFrames();
- tqlayout();
+ layout();
setModified(true);
repaintAllViews( true );
}
@@ -4457,9 +4457,9 @@ void KWDocument::setMailMergeRecord( int r )
slRecordNum = r;
}
-void KWDocument::getPageLayout( KoPageLayout& tqlayout, KoColumns& cl, KoKWHeaderFooter& hf )
+void KWDocument::getPageLayout( KoPageLayout& layout, KoColumns& cl, KoKWHeaderFooter& hf )
{
- tqlayout = m_pageLayout;
+ layout = m_pageLayout;
cl = m_pageColumns;
hf = m_pageHeaderFooter;
}
@@ -4560,12 +4560,12 @@ void KWDocument::printDebug()
}
#endif
-void KWDocument::tqlayout()
+void KWDocument::layout()
{
TQPtrListIterator<KWFrameSet> it = framesetsIterator();
for (; it.current(); ++it )
if ( it.current()->isVisible() )
- it.current()->tqlayout();
+ it.current()->layout();
}
void KWDocument::invalidate(const KWFrameSet *skipThisFrameSet)
@@ -5083,7 +5083,7 @@ void KWDocument::setTabStopValue ( double tabStop )
KWTextFrameSet *frm;
for ( frm=textFramesets.first(); frm != 0; frm=textFramesets.next() ){
frm->textDocument()->setTabStops( ptToLayoutUnitPixX( tabStop ));
- frm->tqlayout();
+ frm->layout();
}
repaintAllViews();
}
@@ -5120,11 +5120,11 @@ void KWDocument::switchViewMode( const TQString& newViewModeType )
(*it)->switchModeView();
emit newContentsSize();
- // Since the text tqlayout depends on the view mode, we need to redo it
+ // Since the text layout depends on the view mode, we need to redo it
// But after telling the canvas about the new viewmode, otherwise stuff like
// slotNewContentsSize will crash.
updateAllFrames();
- tqlayout();
+ layout();
repaintAllViews( true );
for( TQValueList<KWView *>::Iterator it = m_lstViews.begin(); it != m_lstViews.end(); ++it )
@@ -5466,15 +5466,15 @@ void KWDocument::FramesChangedHandler::execute() {
KWFrameSet *fs = *iter;
fs->updateFrames();
if(!m_needLayout)
- fs->tqlayout();
+ fs->layout();
}
KWFrameList::recalcAllFrames(m_parent);
}
- // If frame with text flowing around it -> re-tqlayout all frames
+ // If frame with text flowing around it -> re-layout all frames
if ( m_needLayout)
- m_parent->tqlayout();
+ m_parent->layout();
//m_parent->repaintAllViewsExcept( 0 );
m_parent->repaintAllViews();
m_parent->updateRulerFrameStartEnd();
diff --git a/kword/KWDocument.h b/kword/KWDocument.h
index 26cfe37a..1a9aa16e 100644
--- a/kword/KWDocument.h
+++ b/kword/KWDocument.h
@@ -214,9 +214,9 @@ public:
/// because KoDocument:insertChild is protected.
KWDocumentChild* createChildDoc( const KoRect& rect, KoDocument* childDoc );
- void setPageLayout( const KoPageLayout& tqlayout, const KoColumns& cl, const KoKWHeaderFooter& hf, bool updateViews = true );
+ void setPageLayout( const KoPageLayout& layout, const KoColumns& cl, const KoKWHeaderFooter& hf, bool updateViews = true );
- void getPageLayout( KoPageLayout& tqlayout, KoColumns& cl, KoKWHeaderFooter& hf );
+ void getPageLayout( KoPageLayout& layout, KoColumns& cl, KoKWHeaderFooter& hf );
KWTextFrameSet * textFrameSet ( unsigned int num ) const;
/// Return the frameset number @p num
@@ -273,7 +273,7 @@ public:
void delayedRepaintAllViews();
/**
- * schedule a frame tqlayout (e.g. for footnotes) but don't execute immediately
+ * schedule a frame layout (e.g. for footnotes) but don't execute immediately
*/
void delayedRecalcFrames( int fromPage );
@@ -437,7 +437,7 @@ public:
//int applyStyleChangeMask() { return styleMask; }
//void setApplyStyleChangeMask( int f ) { styleMask = f; }
- // paragLayoutChanged is a set of flags for the parag tqlayout - see the enum in KWParagLayout
+ // paragLayoutChanged is a set of flags for the parag layout - see the enum in KWParagLayout
// formatChanged is a set of flags from KoTextFormat
// If both are -1, it means the style has been deleted.
void applyStyleChange( KoStyleChangeDefMap changed );
@@ -519,7 +519,7 @@ public:
void newZoomAndResolution( bool updateViews, bool forPrint );
/**
- * Due to the way the text formatter works (it caches tqlayout information in
+ * Due to the way the text formatter works (it caches layout information in
* the paragraphs and characters), we currently can't have one viewmode per view.
* It has to be the same for all views.
*/
@@ -565,8 +565,8 @@ public:
void printDebug();
#endif
- /** calls tqlayout() on all framesets */
- void tqlayout();
+ /** calls layout() on all framesets */
+ void layout();
// This settings has to be here [instead of KWView] because we need to
// format paragraphs slightly differently (to add room for the CR char)
@@ -764,7 +764,7 @@ public:
KWBgSpellCheck* backSpeller() const { return m_bgSpellCheck; }
- /// Load the given page tqlayout; public for KWTextParag
+ /// Load the given page layout; public for KWTextParag
bool loadOasisPageLayout( const TQString& masterPageName, KoOasisContext& context );
// end of public methods
@@ -773,7 +773,7 @@ signals:
/// This is emitted by setPageLayout if updateViews=true
void pageLayoutChanged( const KoPageLayout& );
- /// Emitted when the scrollview contents must be resized (e.g. new page, new tqlayout...)
+ /// Emitted when the scrollview contents must be resized (e.g. new page, new layout...)
void newContentsSize();
/** This is emitted when the height of the text in the main frameset changes
diff --git a/kword/KWEditPersonnalExpression.cpp b/kword/KWEditPersonnalExpression.cpp
index 281bf033..4a870af7 100644
--- a/kword/KWEditPersonnalExpression.cpp
+++ b/kword/KWEditPersonnalExpression.cpp
@@ -40,23 +40,23 @@ KWEditPersonnalExpression::KWEditPersonnalExpression( TQWidget *parent, const ch
setMainWidget(page);
TQGridLayout* form1Layout = new TQGridLayout( page, 1, 1, 0, KDialog::spacingHint(), "form1Layout");
- TQHBoxLayout *hortqlayout1 = new TQHBoxLayout( 0, 0, KDialog::spacingHint(), "hortqlayout1");
+ TQHBoxLayout *horlayout1 = new TQHBoxLayout( 0, 0, KDialog::spacingHint(), "horlayout1");
TQLabel *groupnameLabel = new TQLabel(i18n("Group name:"), page, "groupnameLabel" );
- hortqlayout1->addWidget( groupnameLabel );
+ horlayout1->addWidget( groupnameLabel );
m_groupLineEdit = new TQLineEdit( page, "groupLineEdit" );
- hortqlayout1->addWidget( m_groupLineEdit );
+ horlayout1->addWidget( m_groupLineEdit );
- form1Layout->addLayout( hortqlayout1, 0, 1 );
+ form1Layout->addLayout( horlayout1, 0, 1 );
TQGroupBox *expressionGroupBox = new TQGroupBox( page, "expressionGroupBox" );
expressionGroupBox->setSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)5, (TQSizePolicy::SizeType)5, 1, 0, expressionGroupBox->sizePolicy().hasHeightForWidth() ) );
expressionGroupBox->setTitle( i18n( "Expressions" ) );
expressionGroupBox->setColumnLayout(0, Qt::Vertical );
- expressionGroupBox->tqlayout()->setSpacing( KDialog::spacingHint() );
- expressionGroupBox->tqlayout()->setMargin( KDialog::marginHint() );
- TQVBoxLayout *expressionGroupBoxLayout = new TQVBoxLayout( expressionGroupBox->tqlayout() );
+ expressionGroupBox->layout()->setSpacing( KDialog::spacingHint() );
+ expressionGroupBox->layout()->setMargin( KDialog::marginHint() );
+ TQVBoxLayout *expressionGroupBoxLayout = new TQVBoxLayout( expressionGroupBox->layout() );
expressionGroupBoxLayout->setAlignment( TQt::AlignTop );
m_ExpressionsList = new TQListBox( expressionGroupBox, "listOfExpressions" );
@@ -66,36 +66,36 @@ KWEditPersonnalExpression::KWEditPersonnalExpression( TQWidget *parent, const ch
m_expressionLineEdit = new TQLineEdit( expressionGroupBox, "expressionLineEdit" );
expressionGroupBoxLayout->addWidget( m_expressionLineEdit );
- TQHBoxLayout *hortqlayout2 = new TQHBoxLayout( 0, 0, KDialog::spacingHint(), "hortqlayout2");
+ TQHBoxLayout *horlayout2 = new TQHBoxLayout( 0, 0, KDialog::spacingHint(), "horlayout2");
TQSpacerItem* spacer = new TQSpacerItem( 0, 0, TQSizePolicy::Expanding, TQSizePolicy::Minimum );
- hortqlayout2->addItem( spacer );
+ horlayout2->addItem( spacer );
m_addExpression = new TQPushButton( i18n("&New"), expressionGroupBox, "m_addExpression" );
- hortqlayout2->addWidget( m_addExpression );
+ horlayout2->addWidget( m_addExpression );
m_delExpression = new TQPushButton( i18n("&Delete"), expressionGroupBox, "m_delExpression" );
- hortqlayout2->addWidget( m_delExpression );
- expressionGroupBoxLayout->addLayout( hortqlayout2 );
+ horlayout2->addWidget( m_delExpression );
+ expressionGroupBoxLayout->addLayout( horlayout2 );
form1Layout->addWidget( expressionGroupBox, 1, 1 );
- TQVBoxLayout *verttqlayout = new TQVBoxLayout( 0, 0, KDialog::spacingHint(), "verttqlayout");
+ TQVBoxLayout *vertlayout = new TQVBoxLayout( 0, 0, KDialog::spacingHint(), "vertlayout");
m_groupList = new TQListBox( page, "groupList" );
m_groupList->insertItem( "group1" );
m_groupList->setMaximumSize( TQSize( 200, 32767 ) );
- verttqlayout->addWidget( m_groupList );
+ vertlayout->addWidget( m_groupList );
- TQHBoxLayout *hortqlayout3 = new TQHBoxLayout( 0, 0, KDialog::spacingHint(), "hortqlayout3");
+ TQHBoxLayout *horlayout3 = new TQHBoxLayout( 0, 0, KDialog::spacingHint(), "horlayout3");
m_addGroup = new TQPushButton( i18n("New"), page, "m_addGroup" );
- hortqlayout3->addWidget( m_addGroup );
+ horlayout3->addWidget( m_addGroup );
m_delGroup = new TQPushButton(i18n("Delete"), page, "m_delGroup" );
- hortqlayout3->addWidget( m_delGroup );
- verttqlayout->addLayout( hortqlayout3 );
+ horlayout3->addWidget( m_delGroup );
+ vertlayout->addLayout( horlayout3 );
- form1Layout->addMultiCellLayout( verttqlayout, 0, 1, 0, 0 );
+ form1Layout->addMultiCellLayout( vertlayout, 0, 1, 0, 0 );
loadFile();
if(listExpression.count() == 0)
diff --git a/kword/KWFormulaFrameSet.cpp b/kword/KWFormulaFrameSet.cpp
index f8d597e8..f54942a4 100644
--- a/kword/KWFormulaFrameSet.cpp
+++ b/kword/KWFormulaFrameSet.cpp
@@ -219,7 +219,7 @@ void KWFormulaFrameSet::slotFormulaChanged( double width, double height )
m_frames.first()->setHeight( height );
updateFrames();
- kWordDocument()->tqlayout();
+ kWordDocument()->layout();
if ( ( oldWidth != width ) || ( oldHeight != height ) ) {
kWordDocument()->repaintAllViews( false );
kWordDocument()->updateRulerFrameStartEnd();
diff --git a/kword/KWFrame.h b/kword/KWFrame.h
index 88552259..76e17da2 100644
--- a/kword/KWFrame.h
+++ b/kword/KWFrame.h
@@ -221,7 +221,7 @@ public:
/** The "internal Y" is the offset (in pt) of the real frame showed in this one
* ("real" means "the last that isn't a copy")
* This offset in pt is the sum of the height of the frames before that one.
- * For text frames, this is equivalent to the tqlayout units (after multiplication). */
+ * For text frames, this is equivalent to the layout units (after multiplication). */
void setInternalY( double y ) { m_internalY = y; }
double internalY() const { return m_internalY; }
diff --git a/kword/KWFrameDia.cpp b/kword/KWFrameDia.cpp
index ba6f6276..6c7fa4b2 100644
--- a/kword/KWFrameDia.cpp
+++ b/kword/KWFrameDia.cpp
@@ -614,8 +614,8 @@ void KWFrameDia::setupTab2() { // TAB Text Runaround
// First groupbox
m_runGroup = new TQButtonGroup( i18n( "Layout of Text in Other Frames" ), m_tab2);
m_runGroup->setColumnLayout( 0, Qt::Vertical );
- m_runGroup->tqlayout()->setSpacing( KDialog::spacingHint() );
- TQGridLayout *groupBox1Layout = new TQGridLayout( m_runGroup->tqlayout() );
+ m_runGroup->layout()->setSpacing( KDialog::spacingHint() );
+ TQGridLayout *groupBox1Layout = new TQGridLayout( m_runGroup->layout() );
groupBox1Layout->setAlignment( TQt::AlignTop );
m_rRunNo = new TQRadioButton( i18n( "Text will run &through this frame" ), m_runGroup );
@@ -650,9 +650,9 @@ void KWFrameDia::setupTab2() { // TAB Text Runaround
// Second groupbox
m_runSideGroup = new TQButtonGroup( i18n( "Run Around Side" ), m_tab2);
m_runSideGroup->setColumnLayout( 0, Qt::Vertical );
- m_runSideGroup->tqlayout()->setSpacing( KDialog::spacingHint() );
- m_runSideGroup->tqlayout()->setMargin( KDialog::marginHint() );
- TQGridLayout *runSideLayout = new TQGridLayout( m_runSideGroup->tqlayout() );
+ m_runSideGroup->layout()->setSpacing( KDialog::spacingHint() );
+ m_runSideGroup->layout()->setMargin( KDialog::marginHint() );
+ TQGridLayout *runSideLayout = new TQGridLayout( m_runSideGroup->layout() );
runSideLayout->setAlignment( TQt::AlignTop );
m_rRunLeft = new TQRadioButton( i18n( "Run Around", "&Left" ), m_runSideGroup );
@@ -803,9 +803,9 @@ void KWFrameDia::setupTab3(){ // TAB Frameset
myGroup->insert(m_rExistingFrameset,1);
connect (m_rExistingFrameset, TQT_SIGNAL( toggled(bool)), this, TQT_SLOT(ensureValidFramesetSelected()));
- TQHBoxLayout *tqlayout2 = new TQHBoxLayout( 0, 0, 6);
+ TQHBoxLayout *layout2 = new TQHBoxLayout( 0, 0, 6);
TQSpacerItem* spacer = new TQSpacerItem( 20, 20, TQSizePolicy::Minimum, TQSizePolicy::Expanding );
- tqlayout2->addItem( spacer );
+ layout2->addItem( spacer );
m_lFrameSList = new TQListView( m_tab3, "m_lFrameSList" );
m_lFrameSList->addColumn( i18n("No.") );
@@ -815,8 +815,8 @@ void KWFrameDia::setupTab3(){ // TAB Frameset
connect( m_lFrameSList, TQT_SIGNAL(selectionChanged ()),this,TQT_SLOT(selectExistingFrameset ()) );
connect (m_lFrameSList, TQT_SIGNAL( selectionChanged()), this, TQT_SLOT(ensureValidFramesetSelected()));
- tqlayout2->addWidget( m_lFrameSList );
- tabLayout->addLayout( tqlayout2 );
+ layout2->addWidget( m_lFrameSList );
+ tabLayout->addLayout( layout2 );
m_rNewFrameset = new TQRadioButton( m_tab3);
m_rNewFrameset->setText( i18n( "Create a new frameset" ) );
@@ -829,14 +829,14 @@ void KWFrameDia::setupTab3(){ // TAB Frameset
line1->setFrameShape( TQFrame::HLine );
tabLayout->addWidget( line1 );
- TQHBoxLayout *tqlayout1 = new TQHBoxLayout( 0, 0, 6 );
+ TQHBoxLayout *layout1 = new TQHBoxLayout( 0, 0, 6 );
TQLabel *textLabel1 = new TQLabel( m_tab3 );
textLabel1->setText( i18n( "Name of frameset:" ) );
- tqlayout1->addWidget( textLabel1 );
+ layout1->addWidget( textLabel1 );
m_eFrameSetName = new TQLineEdit( m_tab3 );
- tqlayout1->addWidget( m_eFrameSetName );
- tabLayout->addLayout( tqlayout1 );
+ layout1->addWidget( m_eFrameSetName );
+ tabLayout->addLayout( layout1 );
int amount=0;
// now fill the gui.
@@ -1290,10 +1290,10 @@ void KWFrameDia::setupTab6() // Border style
TQGroupBox *grp=new TQGroupBox( 0, Qt::Vertical, i18n( "Preview" ), m_tab6, "previewgrp" );
grid->addMultiCellWidget( grp , 0, 7, 1, 1 );
- grp->tqlayout()->setSpacing(KDialog::spacingHint());
- grp->tqlayout()->setMargin(KDialog::marginHint());
+ grp->layout()->setSpacing(KDialog::spacingHint());
+ grp->layout()->setMargin(KDialog::marginHint());
m_prev3 = new KoBorderPreview( grp );
- TQVBoxLayout *lay1 = new TQVBoxLayout( grp->tqlayout() );
+ TQVBoxLayout *lay1 = new TQVBoxLayout( grp->layout() );
lay1->addWidget(m_prev3);
connect( m_prev3, TQT_SIGNAL( choosearea(TQMouseEvent * ) ),
@@ -2330,7 +2330,7 @@ bool KWFrameDia::applyChanges()
void KWFrameDia::updateFrames()
{
m_doc->updateAllFrames();
- m_doc->tqlayout();
+ m_doc->layout();
m_doc->repaintAllViews();
}
diff --git a/kword/KWFrameLayout.cpp b/kword/KWFrameLayout.cpp
index 685f81e6..8db6227a 100644
--- a/kword/KWFrameLayout.cpp
+++ b/kword/KWFrameLayout.cpp
@@ -38,7 +38,7 @@ KWFrameLayout::HeaderFooterFrameset::HeaderFooterFrameset( KWTextFrameSet* fs, i
if ( fs->frameCount() > 0 )
m_height = fs->frame(0)->height();
else
- m_height = 20; // whatever. The text tqlayout will resize it.
+ m_height = 20; // whatever. The text layout will resize it.
Q_ASSERT( m_height > 0 );
}
@@ -129,13 +129,13 @@ int KWFrameLayout::HeaderFooterFrameset::frameNumberForPage( int page ) const
/////
-void KWFrameLayout::tqlayout( KWFrameSet* mainTextFrameSet, int numColumns,
+void KWFrameLayout::layout( KWFrameSet* mainTextFrameSet, int numColumns,
int fromPage, int toPage, uint flags )
{
- //kdDebug(32002) << "KWFrameLayout::tqlayout " << kdBacktrace() << endl;
+ //kdDebug(32002) << "KWFrameLayout::layout " << kdBacktrace() << endl;
// Just debug stuff
#ifdef DEBUG_FRAMELAYOUT
- kdDebug(32002) << "KWFrameLayout::tqlayout " << fromPage << " to " << toPage << endl;
+ kdDebug(32002) << "KWFrameLayout::layout " << fromPage << " to " << toPage << endl;
Q_ASSERT( toPage >= fromPage );
TQPtrListIterator<HeaderFooterFrameset> itdbg( m_headersFooters );
for ( ; itdbg.current() ; ++itdbg )
@@ -493,8 +493,8 @@ void KWFrameLayout::tqlayout( KWFrameSet* mainTextFrameSet, int numColumns,
// Not right now, this could be called during formatting...
//m_doc->invalidate();
- // ### This means the tqlayout will be done during painting. Not good.
- // What about mainTextFrameSet->invalidate() or even tqlayout()?
+ // ### This means the layout will be done during painting. Not good.
+ // What about mainTextFrameSet->invalidate() or even layout()?
//TQTimer::singleShot( 0, m_doc, TQT_SLOT( invalidate() ) );
// Invalidate main textframeset only, and from top of page only.
@@ -549,8 +549,8 @@ void KWFrameLayout::resizeOrCreateHeaderFooter( KWTextFrameSet* headerFooter, ui
m_framesetsToUpdate.insert( headerFooter, true );
}
-// Called at beginning and end of the tqlayout for a given page,
-// to determine if the main-text-frame tqlayout really changed or not.
+// Called at beginning and end of the layout for a given page,
+// to determine if the main-text-frame layout really changed or not.
// Testing in resizeMainTextFrame doesn't work, we call it several times,
// once for each footnote, so it can't detect the "no change" case.
KoRect KWFrameLayout::firstColumnRect( KWFrameSet* mainTextFrameSet, int pageNum, int numColumns ) const
diff --git a/kword/KWFrameSet.cpp b/kword/KWFrameSet.cpp
index 9a1d43ba..ec5cf7db 100644
--- a/kword/KWFrameSet.cpp
+++ b/kword/KWFrameSet.cpp
@@ -292,7 +292,7 @@ void KWFrameSet::setFloating()
frameSet->findPosition( dPoint, parag, index );
// Create anchor. TODO: refcount the anchors!
setAnchored( frameSet, parag, index );
- frameSet->tqlayout();
+ frameSet->layout();
m_doc->frameChanged( m_frames.first() );
return;
}
diff --git a/kword/KWFrameSet.h b/kword/KWFrameSet.h
index 50294045..67cad0da 100644
--- a/kword/KWFrameSet.h
+++ b/kword/KWFrameSet.h
@@ -310,8 +310,8 @@ public:
/** Allows to detect that updateFrames() hasn't been called yet (e.g. on loading) */
bool hasFramesInPageArray() const { return !m_framesInPage.isEmpty(); }
- /** retqlayout text in frames, so that it flows correctly around other frames */
- virtual void tqlayout() {}
+ /** relayout text in frames, so that it flows correctly around other frames */
+ virtual void layout() {}
virtual void invalidate() {}
/// save to XML - when saving
diff --git a/kword/KWFrameStyleManager.cpp b/kword/KWFrameStyleManager.cpp
index 19ad2b00..b9ccbe16 100644
--- a/kword/KWFrameStyleManager.cpp
+++ b/kword/KWFrameStyleManager.cpp
@@ -235,9 +235,9 @@ void KWFrameStyleManager::addGeneralTab()
tabLayout->setMargin( KDialog::marginHint() );
previewBox = new TQGroupBox( 0, Qt::Vertical, i18n( "Preview" ), tab );
- previewBox->tqlayout()->setSpacing(KDialog::spacingHint());
- previewBox->tqlayout()->setMargin(KDialog::marginHint());
- TQGridLayout *previewLayout = new TQGridLayout( previewBox->tqlayout() );
+ previewBox->layout()->setSpacing(KDialog::spacingHint());
+ previewBox->layout()->setMargin(KDialog::marginHint());
+ TQGridLayout *previewLayout = new TQGridLayout( previewBox->layout() );
preview = new KWFrameStylePreview( previewBox );
preview->resize(preview->sizeHint());
diff --git a/kword/KWImportStyleDia.cpp b/kword/KWImportStyleDia.cpp
index 1b2666df..93ec0334 100644
--- a/kword/KWImportStyleDia.cpp
+++ b/kword/KWImportStyleDia.cpp
@@ -99,7 +99,7 @@ void KWImportStyleDia::loadFile()
TQDomElement styleElem = listStyles.item( item ).toElement();
KoParagStyle *sty = new KoParagStyle( TQString() );
- // Load the paragtqlayout from the <STYLE> element
+ // Load the paraglayout from the <STYLE> element
sty->loadStyle( styleElem, m_doc->syntaxVersion() ); //#### wrong syntaxVersion!
TQString name = sty->displayName();
diff --git a/kword/KWInsertPageDia.cpp b/kword/KWInsertPageDia.cpp
index 28d0cd34..42ca6b22 100644
--- a/kword/KWInsertPageDia.cpp
+++ b/kword/KWInsertPageDia.cpp
@@ -34,7 +34,7 @@ KWInsertPageDia::KWInsertPageDia( TQWidget *parent, const char* name )
TQButtonGroup *grp = new TQButtonGroup( 1, Qt::Horizontal, i18n( "Insert Page" ),page );
grp->setRadioButtonExclusive( TRUE );
- grp->tqlayout();
+ grp->layout();
m_after = new TQRadioButton( i18n("After"), grp );
m_before = new TQRadioButton( i18n("Before"), grp );
diff --git a/kword/KWInsertTOCCommand.cpp b/kword/KWInsertTOCCommand.cpp
index 33cb2399..ebf6c480 100644
--- a/kword/KWInsertTOCCommand.cpp
+++ b/kword/KWInsertTOCCommand.cpp
@@ -80,7 +80,7 @@ KoTextCursor * KWInsertTOCCommand::execute( KoTextCursor *c )
prevTOCParag->setPageBreaking( prevTOCParag->pageBreaking() | KWParagLayout::HardFrameBreakAfter );
// Format paragraphs, to take this page break into account and update page numbers
- fs->tqlayout();
+ fs->layout();
fs->updateFrames();
//kdDebug() << "KWInsertTOCCommand::execute layouting done, setting page numbers" << endl;
diff --git a/kword/KWMailMergeDataBase.cpp b/kword/KWMailMergeDataBase.cpp
index 9ee21416..b2e2bc73 100644
--- a/kword/KWMailMergeDataBase.cpp
+++ b/kword/KWMailMergeDataBase.cpp
@@ -329,7 +329,7 @@ KWMailMergeChoosePluginDialog::KWMailMergeChoosePluginDialog( KTrader::OfferList
/*parent*/ 0, "", true ), pluginOffers( offers )
{
TQWidget *back = plainPage();
- TQVBoxLayout *tqlayout = new TQVBoxLayout( back, 0, spacingHint() );
+ TQVBoxLayout *layout = new TQVBoxLayout( back, 0, spacingHint() );
TQLabel *label = new TQLabel( i18n( "&Available sources:" ), back );
chooser = new TQComboBox( false, back );
@@ -354,10 +354,10 @@ KWMailMergeChoosePluginDialog::KWMailMergeChoosePluginDialog( KTrader::OfferList
connect( chooser, TQT_SIGNAL( activated( int ) ),
this, TQT_SLOT( pluginChanged( int ) ) );
- tqlayout->addWidget( label );
- tqlayout->addWidget( chooser );
- tqlayout->addWidget( descriptionLabel );
- tqlayout->addStretch( 1 );
+ layout->addWidget( label );
+ layout->addWidget( chooser );
+ layout->addWidget( descriptionLabel );
+ layout->addStretch( 1 );
pluginChanged( 0 );
}
@@ -387,41 +387,41 @@ KWMailMergeConfigDialog::KWMailMergeConfigDialog(TQWidget *parent,KWMailMergeDat
{
db_=db;
TQWidget *back = plainPage();
- TQVBoxLayout *tqlayout=new TQVBoxLayout(back);
+ TQVBoxLayout *layout=new TQVBoxLayout(back);
// TQVBox *back = new TQVBox( page );
- tqlayout->setSpacing( KDialog::spacingHint() );
+ layout->setSpacing( KDialog::spacingHint() );
// TQVBox *row1 = new TQVBox( back );
// row1->setSpacing( KDialog::spacingHint() );
TQLabel *l = new TQLabel( i18n( "Datasource:" ),back );
// l->setMaximumHeight( l->sizeHint().height() );
- tqlayout->addWidget(l);
+ layout->addWidget(l);
TQHBox *row1=new TQHBox(back);
- tqlayout->addWidget(row1);
+ layout->addWidget(row1);
row1->setSpacing( KDialog::spacingHint() );
edit=new TQPushButton(i18n("Edit Current..."),row1);
create=new TQPushButton(i18n("Create New..."),row1);
open=new TQPushButton(i18n("Open Existing..."),row1);
KSeparator *separator1 = new KSeparator(back);
- tqlayout->addWidget(separator1);
+ layout->addWidget(separator1);
l = new TQLabel( i18n( "Merging:" ),back );
- tqlayout->addWidget(l);
+ layout->addWidget(l);
// l->setMaximumHeight( l->sizeHint().height() );
TQHBox *row2=new TQHBox(back);
- tqlayout->addWidget(row2);
+ layout->addWidget(row2);
row2->setSpacing( KDialog::spacingHint() );
preview=new TQPushButton(i18n("Print Preview..."),row2);
document=new TQPushButton(i18n("Create New Document"),row2);
document->hide();
(void) new TQWidget(row2);
- tqlayout->addStretch();
+ layout->addStretch();
KSeparator *separator2 = new KSeparator(back);
- tqlayout->addWidget(separator2);
+ layout->addWidget(separator2);
enableDisableEdit();
@@ -516,8 +516,8 @@ KWMailMergeVariableInsertDia::KWMailMergeVariableInsertDia( TQWidget *parent, KW
m_db=db;
TQWidget *page = plainPage();
- TQVBoxLayout *tqlayout = new TQVBoxLayout( page, marginHint(), spacingHint() );
- tqlayout->setAutoAdd( true );
+ TQVBoxLayout *layout = new TQVBoxLayout( page, marginHint(), spacingHint() );
+ layout->setAutoAdd( true );
TQLabel *l = new TQLabel( i18n( "Name:" ), page );
l->setMaximumHeight( l->sizeHint().height() );
diff --git a/kword/KWMailMergeLabelAction.cpp b/kword/KWMailMergeLabelAction.cpp
index facb6e9d..1487da45 100644
--- a/kword/KWMailMergeLabelAction.cpp
+++ b/kword/KWMailMergeLabelAction.cpp
@@ -72,10 +72,10 @@ protected:
void drawButton( TQPainter * p )
{
// Draw the background
- tqstyle().drawComplexControl( TQStyle::CC_ToolButton, p, this, rect(), colorGroup(),
+ style().drawComplexControl( TQStyle::CC_ToolButton, p, this, rect(), colorGroup(),
TQStyle::Style_Enabled, TQStyle::SC_ToolButton );
// Draw the label
- tqstyle().drawControl( TQStyle::CE_ToolButtonLabel, p, this, rect(), colorGroup(),
+ style().drawControl( TQStyle::CE_ToolButtonLabel, p, this, rect(), colorGroup(),
TQStyle::Style_Enabled );
}
void enterEvent( TQEvent* ) {};
diff --git a/kword/KWOasisLoader.cpp b/kword/KWOasisLoader.cpp
index 42d72b5e..daaa8502 100644
--- a/kword/KWOasisLoader.cpp
+++ b/kword/KWOasisLoader.cpp
@@ -182,7 +182,7 @@ static KWFrameSet::Info headerTypeToFrameInfo( const TQString& localName, bool /
return KWFrameSet::FI_EVEN_FOOTER;
// ######## KWord extension, because I'm too lazy.
- // TODO: the real solution is a separate page tqlayout for the first page.
+ // TODO: the real solution is a separate page layout for the first page.
if ( localName == "header-first" ) // NOT OASIS COMPLIANT
return KWFrameSet::FI_FIRST_HEADER;
if ( localName == "footer-first" ) // NOT OASIS COMPLIANT
diff --git a/kword/KWPageManager.cpp b/kword/KWPageManager.cpp
index 9dc797a6..e13d4099 100644
--- a/kword/KWPageManager.cpp
+++ b/kword/KWPageManager.cpp
@@ -196,8 +196,8 @@ void KWPageManager::removePage(KWPage *page) {
m_pageList.remove(page);
}
-void KWPageManager::setDefaultPage(const KoPageLayout &tqlayout) {
- m_defaultPageLayout = tqlayout;
+void KWPageManager::setDefaultPage(const KoPageLayout &layout) {
+ m_defaultPageLayout = layout;
// make sure we have 1 default, either pageBound or left/right bound.
if(m_defaultPageLayout.ptLeft < 0 || m_defaultPageLayout.ptRight < 0) {
m_defaultPageLayout.ptLeft = -1;
diff --git a/kword/KWPageManager.h b/kword/KWPageManager.h
index 869a68f3..8f09b577 100644
--- a/kword/KWPageManager.h
+++ b/kword/KWPageManager.h
@@ -111,7 +111,7 @@ public:
/// return the effective pageLayout of @p pageNumber combining the default and the page specific ones
const KoPageLayout pageLayout(int pageNumber) const;
- void setDefaultPage(const KoPageLayout &tqlayout);
+ void setDefaultPage(const KoPageLayout &layout);
/**
* Returns the argument point, with altered coordinats if the point happens to be
diff --git a/kword/KWSortDia.cpp b/kword/KWSortDia.cpp
index 047dcf93..fe1f2c7f 100644
--- a/kword/KWSortDia.cpp
+++ b/kword/KWSortDia.cpp
@@ -34,7 +34,7 @@ KWSortDia::KWSortDia( TQWidget *parent, const char* name )
TQButtonGroup *grp = new TQButtonGroup( 1, Qt::Horizontal, i18n( "Sort" ),page );
grp->setRadioButtonExclusive( TRUE );
- grp->tqlayout();
+ grp->layout();
m_increase = new TQRadioButton( i18n("Increase"), grp );
m_decrease = new TQRadioButton( i18n("Decrease"), grp );
diff --git a/kword/KWStartupWidget.cpp b/kword/KWStartupWidget.cpp
index 60dab02b..0499a427 100644
--- a/kword/KWStartupWidget.cpp
+++ b/kword/KWStartupWidget.cpp
@@ -55,9 +55,9 @@ KWStartupWidget::KWStartupWidget(TQWidget *parent, KWDocument *doc, const KoColu
connect (m_WpStyleCheckbox, TQT_SIGNAL(toggled(bool)), m_columnsWidget, TQT_SLOT(setEnableColumns(bool)));
}
-void KWStartupWidget::sizeUpdated(KoPageLayout &tqlayout) {
- m_layout = tqlayout;
- m_columnsWidget->setLayout(tqlayout);
+void KWStartupWidget::sizeUpdated(KoPageLayout &layout) {
+ m_layout = layout;
+ m_columnsWidget->setLayout(layout);
}
void KWStartupWidget::columnsUpdated(KoColumns &columns) {
diff --git a/kword/KWStartupWidget.h b/kword/KWStartupWidget.h
index 8202488c..22460eed 100644
--- a/kword/KWStartupWidget.h
+++ b/kword/KWStartupWidget.h
@@ -43,7 +43,7 @@ public:
KWStartupWidget(TQWidget *parent, KWDocument *doc, const KoColumns &columns);
private slots:
- void sizeUpdated(KoPageLayout &tqlayout);
+ void sizeUpdated(KoPageLayout &layout);
void columnsUpdated(KoColumns &columns);
void buttonClicked();
diff --git a/kword/KWTableFrameSet.cpp b/kword/KWTableFrameSet.cpp
index 2c27dc04..902d5a78 100644
--- a/kword/KWTableFrameSet.cpp
+++ b/kword/KWTableFrameSet.cpp
@@ -2183,10 +2183,10 @@ void KWTableFrameSet::finalize( ) {
KWFrameSet::finalize();
}
-void KWTableFrameSet::tqlayout()
+void KWTableFrameSet::layout()
{
for (TableIter cells(this) ; cells ; ++cells)
- cells->tqlayout();
+ cells->layout();
}
void KWTableFrameSet::invalidate()
diff --git a/kword/KWTableFrameSet.h b/kword/KWTableFrameSet.h
index f2a5803c..d5fdea1a 100644
--- a/kword/KWTableFrameSet.h
+++ b/kword/KWTableFrameSet.h
@@ -473,7 +473,7 @@ public:
virtual void finalize();
virtual void invalidate();
- virtual void tqlayout();
+ virtual void layout();
virtual void updateFrames( int flags = 0xff );
diff --git a/kword/KWTableStyleManager.cpp b/kword/KWTableStyleManager.cpp
index a08a6bc7..de0a8b1b 100644
--- a/kword/KWTableStyleManager.cpp
+++ b/kword/KWTableStyleManager.cpp
@@ -130,7 +130,7 @@ void KWTableStylePreview::drawContents( TQPainter *p )
p->setClipRect( textRect.intersect( fr ) );
p->translate( textRect.x(), textRect.y() );
- TQColorGroup cg = TQApplication::tqpalette().active();
+ TQColorGroup cg = TQApplication::palette().active();
cg.setBrush( TQColorGroup::Base, tableStyle->frameStyle()->backgroundColor() );
m_textdoc->drawWYSIWYG( p, 1, 0, textRect.width() - 1, textRect.height(), cg, m_zoomHandler );
@@ -293,9 +293,9 @@ void KWTableStyleManager::setupMain()
mainLayout->addWidget( nameLabel, 0, 0 );
TQGroupBox *adjustBox = new TQGroupBox( 0, Qt::Vertical, i18n("Adjust"), main);
- adjustBox->tqlayout()->setSpacing(KDialog::spacingHint());
- adjustBox->tqlayout()->setMargin(KDialog::marginHint());
- TQGridLayout *adjustLayout = new TQGridLayout( adjustBox->tqlayout() );
+ adjustBox->layout()->setSpacing(KDialog::spacingHint());
+ adjustBox->layout()->setMargin(KDialog::marginHint());
+ TQGridLayout *adjustLayout = new TQGridLayout( adjustBox->layout() );
TQLabel *frameStyleLabel = new TQLabel( adjustBox );
frameStyleLabel->setText( i18n( "Framestyle:" ) );
diff --git a/kword/KWTableTemplateSelector.cpp b/kword/KWTableTemplateSelector.cpp
index e99083c4..f219b086 100644
--- a/kword/KWTableTemplateSelector.cpp
+++ b/kword/KWTableTemplateSelector.cpp
@@ -207,7 +207,7 @@ void KWTableTemplatePreview::drawCell( TQPainter *p, const KWTableStyle *ts, con
p->setClipRect( textRect.intersect( globalRect ) );
p->translate( textRect.x(), textRect.y() );
- TQColorGroup cg = TQApplication::tqpalette().active();
+ TQColorGroup cg = TQApplication::palette().active();
cg.setBrush( TQColorGroup::Base, ts->frameStyle()->backgroundColor() );
m_textdoc->drawWYSIWYG( p, 1, 0, textRect.width() - 1, textRect.height(), cg, m_zoomHandler );
diff --git a/kword/KWTextParag.cpp b/kword/KWTextParag.cpp
index 0b1aaa9b..41d1749a 100644
--- a/kword/KWTextParag.cpp
+++ b/kword/KWTextParag.cpp
@@ -552,16 +552,16 @@ KoTextFormat KWTextParag::loadFormat( TQDomElement &formatElem, KoTextFormat * r
void KWTextParag::loadLayout( TQDomElement & attributes )
{
- TQDomElement tqlayout = attributes.namedItem( "LAYOUT" ).toElement();
- if ( !tqlayout.isNull() )
+ TQDomElement layout = attributes.namedItem( "LAYOUT" ).toElement();
+ if ( !layout.isNull() )
{
KWDocument * doc = kwTextDocument()->textFrameSet()->kWordDocument();
- KoParagLayout paragLayout = loadParagLayout( tqlayout, doc, true );
+ KoParagLayout paragLayout = loadParagLayout( layout, doc, true );
setParagLayout( paragLayout );
// Load default format from style.
KoTextFormat *defaultFormat = style() ? &style()->format() : 0L;
- TQDomElement formatElem = tqlayout.namedItem( "FORMAT" ).toElement();
+ TQDomElement formatElem = layout.namedItem( "FORMAT" ).toElement();
if ( !formatElem.isNull() )
{
// Load paragraph format
@@ -577,7 +577,7 @@ void KWTextParag::loadLayout( TQDomElement & attributes )
else
{
// Even the simplest import filter should do <LAYOUT><NAME value="Standard"/></LAYOUT>
- kdWarning(32001) << "No LAYOUT tag in PARAGRAPH, dunno what tqlayout to apply" << endl;
+ kdWarning(32001) << "No LAYOUT tag in PARAGRAPH, dunno what layout to apply" << endl;
}
}
@@ -639,7 +639,7 @@ void KWTextParag::loadFormatting( TQDomElement &attributes, int offset, bool loa
// However, as it is an invalid XML character, we must replace it
// or it will be written out while save the file.
KoTextStringChar& ch = string()->at(index);
- if (ch.c.tqunicode()==1)
+ if (ch.c.unicode()==1)
{
kdDebug() << "Replacing TQChar(1) (in KWTextParag::loadFormatting)" << endl;
ch.c='#';
@@ -740,12 +740,12 @@ void KWTextParag::loadFormatting( TQDomElement &attributes, int offset, bool loa
}
}
-void KWTextParag::setParagLayout( const KoParagLayout & tqlayout, int flags, int marginIndex )
+void KWTextParag::setParagLayout( const KoParagLayout & layout, int flags, int marginIndex )
{
- KoTextParag::setParagLayout( tqlayout, flags, marginIndex );
+ KoTextParag::setParagLayout( layout, flags, marginIndex );
if ( flags & KoParagLayout::PageBreaking )
- setPageBreaking( tqlayout.pageBreaking );
+ setPageBreaking( layout.pageBreaking );
}
//////////
@@ -753,7 +753,7 @@ void KWTextParag::setParagLayout( const KoParagLayout & tqlayout, int flags, int
// Create a KoParagLayout from XML.
KoParagLayout KWTextParag::loadParagLayout( TQDomElement & parentElem, KWDocument *doc, bool findStyle )
{
- KoParagLayout tqlayout;
+ KoParagLayout layout;
// Only when loading paragraphs, not when loading styles
if ( findStyle )
@@ -779,12 +779,12 @@ KoParagLayout KWTextParag::loadParagLayout( TQDomElement & parentElem, KWDocumen
style = doc->styleCollection()->findStyle( "Standard" );
}
Q_ASSERT(style);
- tqlayout.style = style;
+ layout.style = style;
}
- KoParagLayout::loadParagLayout( tqlayout, parentElem, doc->syntaxVersion() );
+ KoParagLayout::loadParagLayout( layout, parentElem, doc->syntaxVersion() );
- return tqlayout;
+ return layout;
}
void KWTextParag::join( KoTextParag *parag )
@@ -808,10 +808,10 @@ void KWTextParag::loadOasis( const TQDomElement& paragElement, KoOasisContext& c
const TQDomElement* paragraphStyle = context.oasisStyles().findStyle( styleName, "paragraph" );
TQString masterPageName = paragraphStyle ? paragraphStyle->attributeNS( KoXmlNS::style, "master-page-name", TQString() ) : TQString();
- // In KWord we don't support sections so the first paragraph is the one that determines the page tqlayout.
+ // In KWord we don't support sections so the first paragraph is the one that determines the page layout.
if ( prev() == 0 ) {
if ( masterPageName.isEmpty() )
- masterPageName = "Standard"; // Seems to be a builtin name for the default tqlayout...
+ masterPageName = "Standard"; // Seems to be a builtin name for the default layout...
currentMasterPageRef = masterPageName; // do this first to avoid recursion
context.styleStack().save();
context.styleStack().setTypeProperties( "paragraph" );
@@ -822,18 +822,18 @@ void KWTextParag::loadOasis( const TQDomElement& paragElement, KoOasisContext& c
doc->variableCollection()->variableSetting()->setStartingPageNumber( pageNumber.toInt() );
context.styleStack().restore();
- doc->loadOasisPageLayout( masterPageName, context ); // page tqlayout
+ doc->loadOasisPageLayout( masterPageName, context ); // page layout
}
else if ( !masterPageName.isEmpty() // empty means no change
&& masterPageName != currentMasterPageRef )
{
- // Detected a change in the master page -> this means we have to use a new page tqlayout
+ // Detected a change in the master page -> this means we have to use a new page layout
// and insert a frame break if not on the first paragraph.
kdDebug(32001) << "KWTextParag::loadOasis: change of master page detected: from " << currentMasterPageRef << " to " << masterPageName << " -> inserting page break" << endl;
currentMasterPageRef = masterPageName;
// [see also KoParagLayout for the 'normal' way to insert page breaks]
m_layout.pageBreaking |= KoParagLayout::HardFrameBreakBefore;
- // We have no way to load/use the new page tqlayout, KWord doesn't have "sections".
+ // We have no way to load/use the new page layout, KWord doesn't have "sections".
}
}
}
diff --git a/kword/KWTextParag.h b/kword/KWTextParag.h
index b0a9d044..de484a48 100644
--- a/kword/KWTextParag.h
+++ b/kword/KWTextParag.h
@@ -46,7 +46,7 @@ public:
KWTextDocument * kwTextDocument() const;
- virtual void setParagLayout( const KoParagLayout &tqlayout, int flags = KoParagLayout::All, int marginIndex = -1 );
+ virtual void setParagLayout( const KoParagLayout &layout, int flags = KoParagLayout::All, int marginIndex = -1 );
/** The type of page-breaking behaviour */
void setPageBreaking( int pb ); // warning this sets all the flags!
@@ -73,7 +73,7 @@ public:
/** Load (from KWord-1.3 XML) and apply \<FORMAT\> tags (used by KWTextParag::load and by KWPasteCommand) */
void loadFormatting( TQDomElement &attributes, int offset = 0, bool loadFootNote=true );
- /** Load (from KWord-1.3 XML) and apply paragraph tqlayout */
+ /** Load (from KWord-1.3 XML) and apply paragraph layout */
void loadLayout( TQDomElement & attributes );
/** Load (from KWord-1.3 XML), optionally using styles from document. */
diff --git a/kword/KWView.cpp b/kword/KWView.cpp
index b39cac7f..832711d1 100644
--- a/kword/KWView.cpp
+++ b/kword/KWView.cpp
@@ -339,7 +339,7 @@ KWView::KWView( const TQString& viewMode, TQWidget *parent, const char *name, KW
connect( frameViewManager(), TQT_SIGNAL(sigFrameSetRenamed()),
TQT_TQOBJECT(this), TQT_SLOT( updateFrameStatusBarItem()));
- connect( TQApplication::tqclipboard(), TQT_SIGNAL( dataChanged() ),
+ connect( TQApplication::clipboard(), TQT_SIGNAL( dataChanged() ),
TQT_TQOBJECT(this), TQT_SLOT( clipboardDataChanged() ) );
connect( m_gui->canvasWidget(), TQT_SIGNAL(currentFrameSetEditChanged()),
@@ -640,7 +640,7 @@ void KWView::setupActions()
TQT_TQOBJECT(this), TQT_SLOT( viewTextMode() ),
actionCollection(), "view_textmode" );
m_actionViewTextMode->setToolTip( i18n( "Only show the text of the document." ) );
- m_actionViewTextMode->setWhatsThis( i18n( "Do not show any pictures, formatting or tqlayout. KWord will display only the text for editing." ) );
+ m_actionViewTextMode->setWhatsThis( i18n( "Do not show any pictures, formatting or layout. KWord will display only the text for editing." ) );
m_actionViewTextMode->setExclusiveGroup( "viewmodes" );
m_actionViewPageMode = new KToggleAction( i18n( "&Page Mode" ), 0,
@@ -1718,12 +1718,12 @@ void KWView::clipboardDataChanged()
}
KWFrameSetEdit * edit = m_gui->canvasWidget()->currentFrameSetEdit();
// Is there plain text in the clipboard ?
- if ( edit && !TQApplication::tqclipboard()->text().isEmpty() )
+ if ( edit && !TQApplication::clipboard()->text().isEmpty() )
{
m_actionEditPaste->setEnabled(true);
return;
}
- TQMimeSource *data = TQApplication::tqclipboard()->data();
+ TQMimeSource *data = TQApplication::clipboard()->data();
const int provides = checkClipboard( data );
if ( provides & ( ProvidesImage | ProvidesOasis | ProvidesFormula ) )
m_actionEditPaste->setEnabled( true );
@@ -2365,7 +2365,7 @@ void KWView::editCut()
edit->cut();
else {
TQDragObject *drag = m_doc->dragSelected( frameViewManager()->selectedFrames() );
- TQApplication::tqclipboard()->setData( drag );
+ TQApplication::clipboard()->setData( drag );
deleteFrame(false);
}
}
@@ -2377,13 +2377,13 @@ void KWView::editCopy()
edit->copy();
else {
TQDragObject *drag = m_doc->dragSelected( frameViewManager()->selectedFrames() );
- TQApplication::tqclipboard()->setData( drag );
+ TQApplication::clipboard()->setData( drag );
}
}
void KWView::editPaste()
{
- TQMimeSource *data = TQApplication::tqclipboard()->data();
+ TQMimeSource *data = TQApplication::clipboard()->data();
pasteData( data, false );
}
@@ -2423,7 +2423,7 @@ void KWView::pasteData( TQMimeSource* data, bool drop )
provides = ProvidesPlainText;
}
if ( !drop ) // get it again, to avoid crashes
- data = TQApplication::tqclipboard()->data();
+ data = TQApplication::clipboard()->data();
}
KWTextFrameSetEdit * edit = currentTextEdit();
if ( edit && ( provides & ProvidesPlainText ) ) {
@@ -2629,7 +2629,7 @@ void KWView::adjustZOrderOfSelectedFrames(MoveFrameType moveType) {
// Calling updateFrames() on the selected frames' framesets isn't enough,
// we also need other framesets to notice the new frames on top.
m_doc->updateAllFrames();
- m_doc->tqlayout();
+ m_doc->layout();
m_doc->repaintAllViews();
}
@@ -3110,7 +3110,7 @@ void KWView::showZoom( const TQString& zoom )
void KWView::slotViewFormattingChars()
{
m_doc->setViewFormattingChars(m_actionViewFormattingChars->isChecked());
- m_doc->tqlayout(); // Due to the different formatting when this option is activated
+ m_doc->layout(); // Due to the different formatting when this option is activated
m_doc->repaintAllViews();
}
@@ -4370,7 +4370,7 @@ void KWView::tableJoinCells()
return;
}
m_doc->addCommand(cmd);
- m_doc->tqlayout();
+ m_doc->layout();
}
void KWView::tableSplitCells() {
@@ -4405,7 +4405,7 @@ void KWView::tableSplitCells(int cols, int rows)
}
m_doc->addCommand(cmd);
m_doc->updateAllFrames();
- m_doc->tqlayout();
+ m_doc->layout();
frameViewManager()->view(cell->frame(0))->setSelected(true);
}
@@ -4980,10 +4980,10 @@ void KWView::setSpacing( KoParagLayout::SpacingType spacing, const TQString& com
KMacroCommand* macroCmd = 0L;
for ( ; it.current() ; ++it )
{
- KoParagLayout tqlayout( *it.current()->currentParagLayoutFormat() );
- tqlayout.lineSpacingType = spacing;
+ KoParagLayout layout( *it.current()->currentParagLayoutFormat() );
+ layout.lineSpacingType = spacing;
- KCommand *cmd = it.current()->setParagLayoutFormatCommand( &tqlayout, KoParagLayout::LineSpacing );
+ KCommand *cmd = it.current()->setParagLayoutFormatCommand( &layout, KoParagLayout::LineSpacing );
if (cmd)
{
if ( !macroCmd )
@@ -5167,8 +5167,8 @@ void KWView::textIncreaseIndent()
m_doc->addCommand(macroCmd);
if(!lst.isEmpty())
{
- const KoParagLayout *tqlayout=lst.first()->currentParagLayoutFormat();
- showRulerIndent( tqlayout->margins[TQStyleSheetItem::MarginLeft], tqlayout->margins[TQStyleSheetItem::MarginFirstLine], tqlayout->margins[TQStyleSheetItem::MarginRight], lst.first()->rtl());
+ const KoParagLayout *layout=lst.first()->currentParagLayoutFormat();
+ showRulerIndent( layout->margins[TQStyleSheetItem::MarginLeft], layout->margins[TQStyleSheetItem::MarginFirstLine], layout->margins[TQStyleSheetItem::MarginRight], lst.first()->rtl());
}
#if 0
@@ -5216,8 +5216,8 @@ void KWView::textDecreaseIndent()
m_doc->addCommand(macroCmd);
if(!lst.isEmpty())
{
- const KoParagLayout *tqlayout=lst.first()->currentParagLayoutFormat();
- showRulerIndent( tqlayout->margins[TQStyleSheetItem::MarginLeft], tqlayout->margins[TQStyleSheetItem::MarginFirstLine], tqlayout->margins[TQStyleSheetItem::MarginRight], lst.first()->rtl());
+ const KoParagLayout *layout=lst.first()->currentParagLayoutFormat();
+ showRulerIndent( layout->margins[TQStyleSheetItem::MarginLeft], layout->margins[TQStyleSheetItem::MarginFirstLine], layout->margins[TQStyleSheetItem::MarginRight], lst.first()->rtl());
}
@@ -5445,7 +5445,7 @@ void KWView::tabListChanged( const KoTabulatorList & tabList )
m_doc->addCommand(macroCmd);
}
-void KWView::newPageLayout( const KoPageLayout &tqlayout )
+void KWView::newPageLayout( const KoPageLayout &layout )
{
TQString mode = viewMode()->type();
bool state = (mode!="ModeText");
@@ -5457,14 +5457,14 @@ void KWView::newPageLayout( const KoPageLayout &tqlayout )
KoKWHeaderFooter hf;
m_doc->getPageLayout( pgLayout, cl, hf );
- if(tqlayout==pgLayout)
+ if(layout==pgLayout)
return;
KWPageLayoutStruct oldLayout( pgLayout, cl, hf );
- m_doc->setPageLayout( tqlayout, cl, hf );
+ m_doc->setPageLayout( layout, cl, hf );
- KWPageLayoutStruct newLayout( tqlayout, cl, hf );
+ KWPageLayoutStruct newLayout( layout, cl, hf );
KWTextFrameSetEdit *edit = currentTextEdit();
if (edit)
@@ -5473,12 +5473,12 @@ void KWView::newPageLayout( const KoPageLayout &tqlayout )
m_doc->addCommand(cmd);
}
-void KWView::slotPageLayoutChanged( const KoPageLayout& tqlayout )
+void KWView::slotPageLayoutChanged( const KoPageLayout& layout )
{
// This is connected to a signal of KWDocument, so that when the
- // above method, or any other way of changing the page tqlayout happens,
+ // above method, or any other way of changing the page layout happens,
// the rulers are updated in all views.
- viewMode()->setPageLayout( m_gui->getHorzRuler(), m_gui->getVertRuler(), tqlayout );
+ viewMode()->setPageLayout( m_gui->getHorzRuler(), m_gui->getVertRuler(), layout );
m_gui->canvasWidget()->repaintAll();
}
@@ -6586,7 +6586,7 @@ void KWView::switchModeView()
updateZoomControls();
updatePageInfo();
- // set page tqlayout in rulers
+ // set page layout in rulers
canvas->viewMode()->setPageLayout( m_gui->getHorzRuler(), m_gui->getVertRuler(), m_doc->pageLayout() );
}
@@ -7263,7 +7263,7 @@ void KWView::convertToTextBox()
if ( cmd )
macro->addCommand( cmd );
// Auto-resize the frame from its contents
- edit->textFrameSet()->tqlayout();
+ edit->textFrameSet()->layout();
}
m_doc->addCommand( macro );
}
@@ -7618,19 +7618,19 @@ KWGUI::KWGUI( const TQString& viewMode, TQWidget *parent, KWView *daView )
l << 90;
m_panner->setSizes( l );
- KoPageLayout tqlayout = doc->pageLayout();
+ KoPageLayout layout = doc->pageLayout();
m_tabChooser = new KoTabChooser( m_right, KoTabChooser::TAB_ALL );
m_tabChooser->setReadWrite(doc->isReadWrite());
gridLayout->addWidget( m_tabChooser, 0, 0 );
- m_horRuler = new KoRuler( m_right, m_canvas->viewport(), Qt::Horizontal, tqlayout,
+ m_horRuler = new KoRuler( m_right, m_canvas->viewport(), Qt::Horizontal, layout,
KoRuler::F_INDENTS | KoRuler::F_TABS,
doc->unit(), m_tabChooser );
m_horRuler->setReadWrite(doc->isReadWrite());
gridLayout->addWidget( m_horRuler, 0, 1 );
- m_vertRuler = new KoRuler( m_right, m_canvas->viewport(), Qt::Vertical, tqlayout,
+ m_vertRuler = new KoRuler( m_right, m_canvas->viewport(), Qt::Vertical, layout,
0, doc->unit() );
m_vertRuler->setReadWrite(doc->isReadWrite());
gridLayout->addWidget( m_vertRuler, 1, 0 );
diff --git a/kword/KWView.h b/kword/KWView.h
index f023e6c6..c720493b 100644
--- a/kword/KWView.h
+++ b/kword/KWView.h
@@ -350,7 +350,7 @@ public slots:
void configure();
void configureCompletion();
- void newPageLayout( const KoPageLayout &tqlayout );
+ void newPageLayout( const KoPageLayout &layout );
void newLeftIndent( double leftIndent);
void newFirstIndent( double firstIndent);
void newRightIndent( double rightIndent);
@@ -487,7 +487,7 @@ protected slots:
void spellAddAutoCorrect (const TQString & originalword, const TQString & newword);
void slotApplyFont();
void slotApplyParag();
- void slotPageLayoutChanged( const KoPageLayout& tqlayout );
+ void slotPageLayoutChanged( const KoPageLayout& layout );
void slotChangeCaseState(bool b);
void slotChangeCutState(bool b);
void slotCorrectWord();
@@ -868,7 +868,7 @@ protected:
KWDocStruct *m_docStruct;
// The right side
- TQWidget *m_right; // The tqlayout widget.
+ TQWidget *m_right; // The layout widget.
KoTabChooser *m_tabChooser;
KoRuler *m_vertRuler;
diff --git a/kword/KWViewMode.cpp b/kword/KWViewMode.cpp
index c1c6f16e..aba5d83c 100644
--- a/kword/KWViewMode.cpp
+++ b/kword/KWViewMode.cpp
@@ -63,7 +63,7 @@ void KWViewMode::drawOnePageBorder( TQPainter * painter, const TQRect & crect, c
TQRegion pageEmptyRegion = emptySpaceRegion.intersect( pagecrect );
//kdDebug() << "RESULT: pageEmptyRegion: " << pageEmptyRegion << endl;
if ( !pageEmptyRegion.isEmpty() )
- m_doc->eraseEmptySpace( painter, pageEmptyRegion, TQApplication::tqpalette().active().brush( TQColorGroup::Base ) );
+ m_doc->eraseEmptySpace( painter, pageEmptyRegion, TQApplication::palette().active().brush( TQColorGroup::Base ) );
}
}
@@ -74,7 +74,7 @@ TQRect KWViewMode::drawRightShadow( TQPainter * painter, const TQRect & crect, c
if ( !shadowRect.isEmpty() )
{
painter->fillRect( shadowRect,
- TQApplication::tqpalette().active().brush( TQColorGroup::Shadow ) );
+ TQApplication::palette().active().brush( TQColorGroup::Shadow ) );
}
return shadowRect;
}
@@ -85,7 +85,7 @@ TQRect KWViewMode::drawBottomShadow( TQPainter * painter, const TQRect & crect,
shadowRect &= crect; // intersect
if ( !shadowRect.isEmpty() )
painter->fillRect( shadowRect,
- TQApplication::tqpalette().active().brush( TQColorGroup::Shadow ) );
+ TQApplication::palette().active().brush( TQColorGroup::Shadow ) );
return shadowRect;
}
@@ -144,10 +144,10 @@ TQRect KWViewMode::rulerFrameRect()
return TQRect();
}
-void KWViewMode::setPageLayout( KoRuler* hRuler, KoRuler* vRuler, const KoPageLayout& tqlayout )
+void KWViewMode::setPageLayout( KoRuler* hRuler, KoRuler* vRuler, const KoPageLayout& layout )
{
- hRuler->setPageLayout( tqlayout );
- vRuler->setPageLayout( tqlayout );
+ hRuler->setPageLayout( layout );
+ vRuler->setPageLayout( layout );
}
// static
@@ -230,7 +230,7 @@ int KWViewModeNormal::xOffset(KWPage *page, int canvasWidth /* = -1 */) {
void KWViewModeNormal::drawPageBorders( TQPainter * painter, const TQRect & crect, const TQRegion & emptySpaceRegion )
{
painter->save();
- painter->setPen( TQApplication::tqpalette().active().color( TQColorGroup::Dark ) );
+ painter->setPen( TQApplication::palette().active().color( TQColorGroup::Dark ) );
painter->setBrush( TQt::NoBrush );
TQRect pageRect;
@@ -258,7 +258,7 @@ void KWViewModeNormal::drawPageBorders( TQPainter * painter, const TQRect & crec
leftArea &= crect;
if ( !leftArea.isEmpty() ) {
painter->fillRect( leftArea,
- TQApplication::tqpalette().active().brush( TQColorGroup::Mid ) );
+ TQApplication::palette().active().brush( TQColorGroup::Mid ) );
}
// The area on the right of the page
@@ -267,7 +267,7 @@ void KWViewModeNormal::drawPageBorders( TQPainter * painter, const TQRect & crec
if ( !rightArea.isEmpty() )
{
painter->fillRect( rightArea,
- TQApplication::tqpalette().active().brush( TQColorGroup::Mid ) );
+ TQApplication::palette().active().brush( TQColorGroup::Mid ) );
// Draw a shadow
int topOffset = ( page==0 ) ? s_shadowOffset : 0; // leave a few pixels on top, only for first page
@@ -284,7 +284,7 @@ void KWViewModeNormal::drawPageBorders( TQPainter * painter, const TQRect & crec
if ( !repaintRect.isEmpty() )
{
painter->fillRect( repaintRect,
- TQApplication::tqpalette().active().brush( TQColorGroup::Mid ) );
+ TQApplication::palette().active().brush( TQColorGroup::Mid ) );
// Draw a shadow
drawBottomShadow( painter, crect, pageRect, s_shadowOffset );
}
@@ -406,7 +406,7 @@ TQPoint KWViewModePreview::viewToNormal( const TQPoint & vPoint )
void KWViewModePreview::drawPageBorders( TQPainter * painter, const TQRect & crect, const TQRegion & emptySpaceRegion )
{
painter->save();
- painter->setPen( TQApplication::tqpalette().active().color( TQColorGroup::Dark ) );
+ painter->setPen( TQApplication::palette().active().color( TQColorGroup::Dark ) );
painter->setBrush( TQt::NoBrush );
//kdDebug() << "KWViewModePreview::drawPageBorders crect=" << DEBUGRECT( crect ) << endl;
TQRegion grayRegion( crect );
@@ -439,7 +439,7 @@ void KWViewModePreview::drawPageBorders( TQPainter * painter, const TQRect & cre
if ( !grayRegion.isEmpty() )
{
//kdDebug() << "KWViewModePreview::drawPageBorders grayRegion's bounding Rect = " << DEBUGRECT( grayRegion.boundingRect() ) << endl;
- m_doc->eraseEmptySpace( painter, grayRegion, TQApplication::tqpalette().active().brush( TQColorGroup::Mid ) );
+ m_doc->eraseEmptySpace( painter, grayRegion, TQApplication::palette().active().brush( TQColorGroup::Mid ) );
}
painter->restore();
}
@@ -541,7 +541,7 @@ void KWViewModeText::drawPageBorders( TQPainter * painter, const TQRect & crect,
painter->save();
TQRegion grayRegion( crect );
//kdDebug() << "KWViewModeText::drawPageBorders crect=" << grayRegion << endl;
- painter->setPen( TQApplication::tqpalette().active().color( TQColorGroup::Dark ) );
+ painter->setPen( TQApplication::palette().active().color( TQColorGroup::Dark ) );
TQSize cSize = contentsSize();
// Draw a line on the right -- ## or a shadow?
// +1 to be out of the contents, and +1 for TQRect
@@ -562,7 +562,7 @@ void KWViewModeText::drawPageBorders( TQPainter * painter, const TQRect & crect,
}
//kdDebug() << "KWViewModeText::drawPageBorders erasing grayRegion " << grayRegion << endl;
if ( !grayRegion.isEmpty() )
- m_doc->eraseEmptySpace( painter, grayRegion, TQApplication::tqpalette().active().brush( TQColorGroup::Mid ) );
+ m_doc->eraseEmptySpace( painter, grayRegion, TQApplication::palette().active().brush( TQColorGroup::Mid ) );
painter->restore();
}
@@ -571,24 +571,24 @@ TQRect KWViewModeText::rulerFrameRect()
return TQRect( TQPoint(OFFSET, 0), contentsSize() );
}
-void KWViewModeText::setPageLayout( KoRuler* hRuler, KoRuler* vRuler, const KoPageLayout& /*tqlayout*/ )
+void KWViewModeText::setPageLayout( KoRuler* hRuler, KoRuler* vRuler, const KoPageLayout& /*layout*/ )
{
- // Create a dummy page-tqlayout, as if we had a single page englobing the whole text.
- KoPageLayout tqlayout;
- tqlayout.format = PG_CUSTOM;
- tqlayout.orientation = PG_PORTRAIT;
+ // Create a dummy page-layout, as if we had a single page englobing the whole text.
+ KoPageLayout layout;
+ layout.format = PG_CUSTOM;
+ layout.orientation = PG_PORTRAIT;
TQSize cSize = contentsSize();
- tqlayout.ptWidth = m_doc->unzoomItX( cSize.width() );
+ layout.ptWidth = m_doc->unzoomItX( cSize.width() );
tqlayout.ptHeight = m_doc->unzoomItY( cSize.height() );
- //kdDebug() << "KWViewModeText::setPageLayout tqlayout size " << tqlayout.ptWidth << "x" << tqlayout.ptHeight << endl;
- tqlayout.ptLeft = OFFSET;
- tqlayout.ptRight = 0;
- tqlayout.ptTop = 0;
- tqlayout.ptBottom = 0;
- tqlayout.ptBindingSide = 0;
- tqlayout.ptPageEdge = 0;
- hRuler->setPageLayout( tqlayout );
- vRuler->setPageLayout( tqlayout );
+ //kdDebug() << "KWViewModeText::setPageLayout layout size " << layout.ptWidth << "x" << layout.ptHeight << endl;
+ layout.ptLeft = OFFSET;
+ layout.ptRight = 0;
+ layout.ptTop = 0;
+ layout.ptBottom = 0;
+ layout.ptBindingSide = 0;
+ layout.ptPageEdge = 0;
+ hRuler->setPageLayout( layout );
+ vRuler->setPageLayout( layout );
}
bool KWViewModeText::isTextModeFrameset(KWFrameSet *fs) const {
diff --git a/kword/KWViewMode.h b/kword/KWViewMode.h
index fc78779a..fa0ec1d9 100644
--- a/kword/KWViewMode.h
+++ b/kword/KWViewMode.h
@@ -85,9 +85,9 @@ public:
/** The result of this is passed to setFrameStartEnd for both rulers
* (after adjustement with pageCorner()) */
virtual TQRect rulerFrameRect();
- /** Called when the page tqlayout is set, or changes.
+ /** Called when the page layout is set, or changes.
* Usually this is directly passed to KoRuler (for page-based viewmodes) */
- virtual void setPageLayout( KoRuler* hRuler, KoRuler* vRuler, const KoPageLayout& tqlayout );
+ virtual void setPageLayout( KoRuler* hRuler, KoRuler* vRuler, const KoPageLayout& layout );
virtual void drawPageBorders( TQPainter * painter, const TQRect & crect, const TQRegion & emptySpaceRegion ) = 0;
@@ -273,7 +273,7 @@ public:
// There is no page concept. Keep everything relative to (0,0)
virtual TQPoint pageCorner() { return TQPoint( 0, 0 ); }
virtual TQRect rulerFrameRect();
- virtual void setPageLayout( KoRuler* hRuler, KoRuler* vRuler, const KoPageLayout& tqlayout );
+ virtual void setPageLayout( KoRuler* hRuler, KoRuler* vRuler, const KoPageLayout& layout );
virtual void drawPageBorders( TQPainter * painter, const TQRect & crect, const TQRegion & emptySpaceRegion );
virtual const TQString type() const { return "ModeText"; }
diff --git a/kword/KWordFrameSetIface.cpp b/kword/KWordFrameSetIface.cpp
index 928cddb5..e284862e 100644
--- a/kword/KWordFrameSetIface.cpp
+++ b/kword/KWordFrameSetIface.cpp
@@ -135,25 +135,25 @@ bool KWordFrameSetIface::isCopy()const
void KWordFrameSetIface::setPtMarginLeft(double val)
{
m_frame->frame( 0 )->setPaddingLeft(val);
- m_frame->kWordDocument()->tqlayout();
+ m_frame->kWordDocument()->layout();
}
void KWordFrameSetIface::setPtMarginRight(double val)
{
m_frame->frame( 0 )->setPaddingRight(val);
- m_frame->kWordDocument()->tqlayout();
+ m_frame->kWordDocument()->layout();
}
void KWordFrameSetIface::setPtMarginTop(double val)
{
m_frame->frame( 0 )->setPaddingTop(val);
- m_frame->kWordDocument()->tqlayout();
+ m_frame->kWordDocument()->layout();
}
void KWordFrameSetIface::setPtMarginBottom(double val)
{
m_frame->frame( 0 )->setPaddingBottom(val);
- m_frame->kWordDocument()->tqlayout();
+ m_frame->kWordDocument()->layout();
}
TQColor KWordFrameSetIface::leftBorderColor() const
diff --git a/kword/OASIS b/kword/OASIS
index fdbfc016..b840b92d 100644
--- a/kword/OASIS
+++ b/kword/OASIS
@@ -25,7 +25,7 @@ and the page-based DTP mode (page-sequence element).
* Headers and footers
OpenDocument supports odd/even headers and footers using "header" and "header-left".
-But for first page header/footer KWord should create a separate page tqlayout,
+But for first page header/footer KWord should create a separate page layout,
this is not done yet (it uses its own tag instead, as a temporary hack).
Also OpenDocument doesn't allow a different style for header and header-left,
so they must have the same min-size, border, margins...
@@ -60,7 +60,7 @@ List of features that KWord has, but OOo doesn't have, and which are in the Open
List of features that KWord doesn't have, and which OpenDocument has:
(that list would be quite long, but let's list the real-life interoperability problems)
- - lack of section support (changes of page tqlayout, but also changes of column settings
+ - lack of section support (changes of page layout, but also changes of column settings
in the middle of a page)
We could at least keep section styles and section markers (begin/end),
so that load+save preserves it.
diff --git a/kword/mailmerge/kabc/addresspicker.ui b/kword/mailmerge/kabc/addresspicker.ui
index 46ced301..af8f5723 100644
--- a/kword/mailmerge/kabc/addresspicker.ui
+++ b/kword/mailmerge/kabc/addresspicker.ui
@@ -21,7 +21,7 @@
</property>
<widget class="TQLayoutWidget" row="1" column="1">
<property name="name">
- <cstring>tqlayout10</cstring>
+ <cstring>layout10</cstring>
</property>
<vbox>
<property name="name">
@@ -101,7 +101,7 @@
</widget>
<widget class="TQLayoutWidget" row="2" column="0">
<property name="name">
- <cstring>tqlayout1</cstring>
+ <cstring>layout1</cstring>
</property>
<hbox>
<property name="name">
diff --git a/kword/mailmerge/kspread/kwmailmerge_kspread_config.cpp b/kword/mailmerge/kspread/kwmailmerge_kspread_config.cpp
index f08ae82e..aa97d0b2 100644
--- a/kword/mailmerge/kspread/kwmailmerge_kspread_config.cpp
+++ b/kword/mailmerge/kspread/kwmailmerge_kspread_config.cpp
@@ -100,20 +100,20 @@ void KWMailMergeKSpreadConfig::initGUI()
{
TQFrame *page = plainPage();
- TQGridLayout *tqlayout = new TQGridLayout( page, 2, 2, marginHint(), spacingHint() );
+ TQGridLayout *layout = new TQGridLayout( page, 2, 2, marginHint(), spacingHint() );
TQLabel *label = new TQLabel( i18n( "URL:" ), page );
- tqlayout->addWidget( label, 0, 0 );
+ layout->addWidget( label, 0, 0 );
_urlRequester = new KURLRequester( page );
- tqlayout->addWidget( _urlRequester, 0, 1 );
+ layout->addWidget( _urlRequester, 0, 1 );
label = new TQLabel( i18n( "Page number:" ), page );
- tqlayout->addWidget( label, 1, 0 );
+ layout->addWidget( label, 1, 0 );
_pageNumber = new KComboBox( page );
_pageNumber->setEnabled( false );
- tqlayout->addWidget( _pageNumber, 1, 1 );
+ layout->addWidget( _pageNumber, 1, 1 );
connect( _urlRequester->lineEdit() , TQT_SIGNAL( textChanged ( const TQString & ) ), this, TQT_SLOT( slotTextChanged( const TQString & ) ) );
}
diff --git a/kword/tests/KWPageManagerTester.cpp b/kword/tests/KWPageManagerTester.cpp
index 641e6534..9b261d90 100644
--- a/kword/tests/KWPageManagerTester.cpp
+++ b/kword/tests/KWPageManagerTester.cpp
@@ -200,11 +200,11 @@ void KWPageManagerTester::removePages() {
void KWPageManagerTester::pageInfo() {
KWPageManager *pageManager = new KWPageManager();
- KoPageLayout tqlayout;
- tqlayout.ptWidth = 300;
- tqlayout.ptHeight = 600;
- tqlayout.format = PG_DIN_A4;
- pageManager->setDefaultPage(tqlayout);
+ KoPageLayout layout;
+ layout.ptWidth = 300;
+ layout.ptHeight = 600;
+ layout.format = PG_DIN_A4;
+ pageManager->setDefaultPage(layout);
pageManager->setStartPage(1);
KWPage *page1 = pageManager->appendPage();
page1->setWidth(100);
@@ -216,19 +216,19 @@ void KWPageManagerTester::pageInfo() {
CHECK(pageManager->topOfPage(3), 300.0);
CHECK(pageManager->bottomOfPage(3), 900.0);
- tqlayout.ptHeight = 500;
- pageManager->setDefaultPage(tqlayout);
+ layout.ptHeight = 500;
+ pageManager->setDefaultPage(layout);
CHECK(pageManager->bottomOfPage(3), 800.0);
page2->setHeight(-1);
CHECK(pageManager->bottomOfPage(3), 1200.0);
- tqlayout.ptTop = 5;
- tqlayout.ptLeft = 6;
- tqlayout.ptBottom = 7;
- tqlayout.ptRight = 8;
- tqlayout.ptBindingSide = -1;
- tqlayout.ptPageEdge = -1;
- pageManager->setDefaultPage(tqlayout);
+ layout.ptTop = 5;
+ layout.ptLeft = 6;
+ layout.ptBottom = 7;
+ layout.ptRight = 8;
+ layout.ptBindingSide = -1;
+ layout.ptPageEdge = -1;
+ pageManager->setDefaultPage(layout);
page2->setTopMargin(9);
page2->setLeftMargin(10);
page2->setBottomMargin(11);
diff --git a/kword/KWFrameLayout.h b/kword/KWFrameLayout.h
index 18089ee5..c4b3f7eb 100644
--- a/kword/KWFrameLayout.h
+++ b/kword/KWFrameLayout.h
@@ -68,7 +68,7 @@ public:
// frame number for the given page.... -1 if no frame on that page
// The first frame is number 0.
int frameNumberForPage( int page ) const;
// The last frame we need (0-based), tqlayout() will delete any frame after that
int lastFrameNumber( int lastPage ) const;
void debug();
@@ -89,14 +89,14 @@ public:
enum { DontRemovePages = 1 };
/**
* The main method of this file. Do the frame tqlayout.
* @param mainTextFrameSet if set, its frames will be resized. Usually: set in WP mode, not set in DTP mode.
* @param numColumns number of columns to create for the main textframeset. Only relevant if mainTextFrameSet!=0.
* @param fromPage first page to tqlayout ( 0-based )
* @param toPage last page to tqlayout ( 0-based )
* @param flags see enum above
*/
- void tqlayout( KWFrameSet* mainTextFrameSet, int numColumns,
+ void layout( KWFrameSet* mainTextFrameSet, int numColumns,
int fromPage, int toPage, uint flags );
protected:
@@ -68,7 +68,7 @@ public:
// The first frame is number 0.
int frameNumberForPage( int page ) const;
- // The last frame we need (0-based), tqlayout() will delete any frame after that
+ // The last frame we need (0-based), layout() will delete any frame after that
int lastFrameNumber( int lastPage ) const;
void debug();
@@ -89,14 +89,14 @@ public:
enum { DontRemovePages = 1 };
/**
- * The main method of this file. Do the frame tqlayout.
+ * The main method of this file. Do the frame layout.
* @param mainTextFrameSet if set, its frames will be resized. Usually: set in WP mode, not set in DTP mode.
* @param numColumns number of columns to create for the main textframeset. Only relevant if mainTextFrameSet!=0.
@@ -89,14 +89,14 @@ public:
* @param mainTextFrameSet if set, its frames will be resized. Usually: set in WP mode, not set in DTP mode.
* @param numColumns number of columns to create for the main textframeset. Only relevant if mainTextFrameSet!=0.
- * @param fromPage first page to tqlayout ( 0-based )
- * @param toPage last page to tqlayout ( 0-based )
+ * @param fromPage first page to layout ( 0-based )
+ * @param toPage last page to layout ( 0-based )
* @param flags see enum above
*/
diff --git a/kword/KWTextFrameSet.cpp b/kword/KWTextFrameSet.cpp
index 54f9f97d..540794f1 100644
--- a/kword/KWTextFrameSet.cpp
+++ b/kword/KWTextFrameSet.cpp
@@ -396,7 +396,7 @@ KWFrame * KWTextFrameSet::internalToDocumentWithHint( const TQPoint &iPoint, KoP
kdDebug() << "ITD: r=" << r << " iPoint=" << iPoint.x() << "," << iPoint.y() << endl;
#endif
// r is the frame in qrt coords
- if ( r.contains( iPoint ) ) // both r and p are in tqlayout units (aka internal)
+ if ( r.contains( iPoint ) ) // both r and p are in layout units (aka internal)
{
dPoint = internalToDocumentKnowingFrame( iPoint, theFrame );
#ifdef DEBUG_ITD
@@ -757,7 +757,7 @@ void KWTextFrameSet::drawCursor( TQPainter *p, KoTextCursor *cursor, bool cursor
#endif
p->save();
- TQColorGroup cg = TQApplication::tqpalette().active();
+ TQColorGroup cg = TQApplication::palette().active();
if ( hasFrames )
{
@@ -824,7 +824,7 @@ void KWTextFrameSet::drawCursor( TQPainter *p, KoTextCursor *cursor, bool cursor
m_currentDrawnFrame = 0L;
}
-void KWTextFrameSet::tqlayout()
+void KWTextFrameSet::layout()
{
invalidate();
// Get the thing going though, repainting doesn't call formatMore
@@ -835,7 +835,7 @@ void KWTextFrameSet::invalidate()
{
//kdDebug() << "KWTextFrameSet::invalidate " << name() << endl;
m_textobj->setLastFormattedParag( textDocument()->firstParag() );
- textDocument()->invalidate(); // lazy tqlayout, real update follows upon next repaint
+ textDocument()->invalidate(); // lazy layout, real update follows upon next repaint
}
void KWTextFrameSet::slotRepaintChanged()
@@ -960,7 +960,7 @@ void KWTextFrameSet::getMargins( int yp, int h, int reqMinWidth,
if ( validHeight )
*validHeight = h; // TODO
// Everything from there is in tqlayout units
// Note: it is very important that this method works in internal coordinates.
// Otherwise, parags broken at the line-level (e.g. between two columns) are seen
// as still in one piece, and we miss the frames in the 2nd column.
@@ -1984,7 +1984,7 @@ bool KWTextFrameSet::slotAfterFormattingNeedMoreSpace( int bottom, KoTextParag *
frmBehavior = KWFrame::Ignore;
}
- int difference = ( bottom + 2 ) - availHeight; // in tqlayout unit pixels
+ int difference = ( bottom + 2 ) - availHeight; // in layout unit pixels
#ifdef DEBUG_FORMAT_MORE
kdDebug(32002) << "AutoExtendFrame bottom=" << bottom << " availHeight=" << availHeight
<< " => difference = " << difference << endl;
@@ -2484,7 +2484,7 @@ void KWTextFrameSet::frameResized( KWFrame *theFrame, bool invalidateLayout )
m_doc->recalcFrames( theFrame->pageNumber(), -1 ); // warning this can delete theFrame!
// m_doc->frameChanged( theFrame );
// Warning, can't call tqlayout() (frameChanged calls it)
// from here, since it calls formatMore() !
if ( invalidateLayout )
m_doc->invalidate(this);
@@ -2770,7 +2770,7 @@ bool KWTextFrameSet::minMaxInternalOnPage( int pageNum, int& topLU, int& bottomL
topPt = TQMIN( topPt, y );
bottomPt = TQMAX( bottomPt, y + frameIt.current()->height() );
}
// Convert to tqlayout units
topLU = m_doc->ptToLayoutUnitPixY( topPt );
bottomLU = m_doc->ptToLayoutUnitPixY( bottomPt );
return true;
@@ -3146,7 +3146,7 @@ void KWTextFrameSetEdit::slotFrameDeleted( KWFrame *frm )
void KWTextFrameSetEdit::paste()
{
- TQMimeSource *data = TQApplication::tqclipboard()->data();
+ TQMimeSource *data = TQApplication::clipboard()->data();
int provides = KWView::checkClipboard( data );
pasteData( data, provides, false );
}
@@ -3163,7 +3163,7 @@ void KWTextFrameSetEdit::pasteData( TQMimeSource* data, int provides, bool drop
{
// Note: TQClipboard::text() seems to do a better job than encodedData( "text/plain" )
// In particular it handles charsets (in the mimetype).
- const TQString text = TQApplication::tqclipboard()->text();
+ const TQString text = TQApplication::clipboard()->text();
const bool removeSelected = !drop;
if ( !text.isEmpty() )
textObject()->pasteText( cursor(), text, currentFormat(), removeSelected );
@@ -3208,7 +3208,7 @@ void KWTextFrameSetEdit::copy()
{
if ( textDocument()->hasSelection( KoTextDocument::Standard ) ) {
TQDragObject *drag = newDrag( 0 );
- TQApplication::tqclipboard()->setData( drag );
+ TQApplication::clipboard()->setData( drag );
}
}
@@ -3652,9 +3652,9 @@ void KWTextFrameSetEdit::dropEvent( TQDropEvent * e, const TQPoint & nPoint, con
cmd = pasteOasisCommand( e );
if ( cmd )
macroCmd->addCommand(cmd);
- //retqlayout textframeset after a dnd otherwise autoextend
+ //relayout textframeset after a dnd otherwise autoextend
//frameset is not re-layouted
- textFrameSet()->tqlayout();
+ textFrameSet()->layout();
frameSet()->kWordDocument()->addCommand( macroCmd );
}
return;
@@ -960,7 +960,7 @@ void KWTextFrameSet::getMargins( int yp, int h, int reqMinWidth,
if ( validHeight )
*validHeight = h; // TODO
- // Everything from there is in tqlayout units
+ // Everything from there is in layout units
// Note: it is very important that this method works in internal coordinates.
// Otherwise, parags broken at the line-level (e.g. between two columns) are seen
@@ -2484,7 +2484,7 @@ void KWTextFrameSet::frameResized( KWFrame *theFrame, bool invalidateLayout )
m_doc->recalcFrames( theFrame->pageNumber(), -1 ); // warning this can delete theFrame!
// m_doc->frameChanged( theFrame );
- // Warning, can't call tqlayout() (frameChanged calls it)
+ // Warning, can't call layout() (frameChanged calls it)
// from here, since it calls formatMore() !
if ( invalidateLayout )
@@ -2770,7 +2770,7 @@ bool KWTextFrameSet::minMaxInternalOnPage( int pageNum, int& topLU, int& bottomL
bottomPt = TQMAX( bottomPt, y + frameIt.current()->height() );
}
- // Convert to tqlayout units
+ // Convert to layout units
topLU = m_doc->ptToLayoutUnitPixY( topPt );
bottomLU = m_doc->ptToLayoutUnitPixY( bottomPt );
diff --git a/kword/KWTextFrameSet.h b/kword/KWTextFrameSet.h
index 7cc4efb5..aee28007 100644
--- a/kword/KWTextFrameSet.h
+++ b/kword/KWTextFrameSet.h
@@ -93,14 +93,14 @@ public:
void clearUndoRedoInfo();
/** Convert the @p dPoint in the normal coordinate system (and in pt)
* into a point (@p iPoint) in the internal qtextdoc coordinates (in tqlayout units). */
KWFrame * documentToInternal( const KoPoint &dPoint, TQPoint &iPoint ) const;
/// used by documentToInternalMouseSelection()
enum RelativePosition { InsideFrame, LeftOfFrame, TopOfFrame, AtEnd };
KWFrame * documentToInternalMouseSelection( const KoPoint &dPoint, TQPoint &iPoint, RelativePosition& relPos, KWViewMode *viewMode ) const;
/** Convert the @p in the internal qtextdoc coordinates (in tqlayout units)
* into a point in the document coordinate system (in pt).
* Also returns the frame in which this point is. */
KWFrame * internalToDocument( const KoPoint &relPoint, KoPoint &dPoint ) const;
@@ -125,7 +125,7 @@ public:
KoPoint internalToDocumentKnowingFrame( const TQPoint &iPoint, KWFrame* theFrame ) const;
/** Implementation of Ctrl+PageUp/PageDown
* Returns a point in tqlayout units (for placing the cursor) */
TQPoint moveToPage( int currentPgNum, short int direction ) const;
/** Return the available height in pixels (sum of all frames' height, with zoom applied)
@@ -237,7 +237,7 @@ public:
#endif
/** Invalidate all paragraphs and start re-formatting */
- virtual void tqlayout();
+ virtual void layout();
/** Invalidate all paragraphs (causes a re-flow of the text upon next redraw) */
virtual void invalidate();
@@ -275,13 +275,13 @@ public:
/** Let KoTextFormatInterface set the modified format */
virtual KCommand *setFormatCommand( const KoTextFormat * newFormat, int flags, bool zoomFont = false );
/** Let KoTextFormatInterface access the current parag tqlayout */
virtual const KoParagLayout * currentParagLayoutFormat() const;
virtual bool rtl() const ;
- /** Let KoTextFormatInterface set a modified current parag tqlayout */
+ /** Let KoTextFormatInterface set a modified current parag layout */
virtual KCommand *setParagLayoutFormatCommand( KoParagLayout *newLayout, int flags, int marginIndex=-1);
virtual KCommand *setChangeCaseOfTextCommand(KoChangeCaseDia::TypeOfCase _type);
@@ -93,14 +93,14 @@ public:
void clearUndoRedoInfo();
/** Convert the @p dPoint in the normal coordinate system (and in pt)
- * into a point (@p iPoint) in the internal qtextdoc coordinates (in tqlayout units). */
+ * into a point (@p iPoint) in the internal qtextdoc coordinates (in layout units). */
KWFrame * documentToInternal( const KoPoint &dPoint, TQPoint &iPoint ) const;
/// used by documentToInternalMouseSelection()
@@ -93,14 +93,14 @@ public:
enum RelativePosition { InsideFrame, LeftOfFrame, TopOfFrame, AtEnd };
KWFrame * documentToInternalMouseSelection( const KoPoint &dPoint, TQPoint &iPoint, RelativePosition& relPos, KWViewMode *viewMode ) const;
- /** Convert the @p in the internal qtextdoc coordinates (in tqlayout units)
+ /** Convert the @p in the internal qtextdoc coordinates (in layout units)
* into a point in the document coordinate system (in pt).
* Also returns the frame in which this point is. */
@@ -125,7 +125,7 @@ public:
KoPoint internalToDocumentKnowingFrame( const TQPoint &iPoint, KWFrame* theFrame ) const;
/** Implementation of Ctrl+PageUp/PageDown
- * Returns a point in tqlayout units (for placing the cursor) */
+ * Returns a point in layout units (for placing the cursor) */
TQPoint moveToPage( int currentPgNum, short int direction ) const;
/** Return the available height in pixels (sum of all frames' height, with zoom applied)
@@ -275,13 +275,13 @@ public:
/** Let KoTextFormatInterface set the modified format */
virtual KCommand *setFormatCommand( const KoTextFormat * newFormat, int flags, bool zoomFont = false );
- /** Let KoTextFormatInterface access the current parag tqlayout */
+ /** Let KoTextFormatInterface access the current parag layout */
virtual const KoParagLayout * currentParagLayoutFormat() const;
virtual bool rtl() const ;
diff --git a/kword/KWVariable.cpp b/kword/KWVariable.cpp
index 304d5191..80666965 100644
--- a/kword/KWVariable.cpp
+++ b/kword/KWVariable.cpp
@@ -532,7 +532,7 @@ void KWFootNoteVariable::finalize()
fs->textObject()->abortFormatting();
// abortFormatting is a bool in kotextobject. So we need to return there before
// starting text tqlayout again.
m_doc->delayedRecalcFrames( TQMIN( pageNum, framePage ) );
m_doc->delayedRepaintAllViews();
}
@@ -596,7 +596,7 @@ void KWFootNoteVariable::setDeleted( bool del )
m_doc->recalcFrames();
if (!del)
- m_frameset->tqlayout(); // format its text, so that it resizes the frame
+ m_frameset->layout(); // format its text, so that it resizes the frame
KoVariable::setDeleted( del );
// Does this compress? Probably not.
m_doc->delayedRepaintAllViews();
@@ -617,7 +617,7 @@ double KWFootNoteVariable::varY() const
if ( !fs->hasFramesInPageArray() ) // we need it for internalToDocument
{
kdDebug(32001) << "KWFootNoteVariable::varY too early, no updateFrames yet" << endl;
- return 0; // this happens on loading - frame tqlayout is done before text tqlayout
+ return 0; // this happens on loading - frame layout is done before text layout
}
// What we need is "has never been formatted". Not "has just been invalidated"...
//if ( !paragraph()->isValid() )
@@ -532,7 +532,7 @@ void KWFootNoteVariable::finalize()
fs->textObject()->abortFormatting();
// abortFormatting is a bool in kotextobject. So we need to return there before
- // starting text tqlayout again.
+ // starting text layout again.
m_doc->delayedRecalcFrames( TQMIN( pageNum, framePage ) );
m_doc->delayedRepaintAllViews();